within ;
package Modelica "Modelica Standard Library (Version 3.2)"
extends Modelica.Icons.Package;

  package Blocks
    "Library of basic input/output control blocks (continuous, discrete, logical, table blocks)"
  import SI = Modelica.SIunits;
  extends Modelica.Icons.Package;

    package Continuous
      "Library of continuous control blocks with internal states"
      import Modelica.Blocks.Interfaces;
      import Modelica.SIunits;
      extends Modelica.Icons.Package;

      block Integrator "Output the integral of the input signal"
        import Modelica.Blocks.Types.Init;
        parameter Real k(unit="1")=1 "Integrator gain";

        /* InitialState is the default, because it was the default in Modelica 2.2
     and therefore this setting is backward compatible
  */
        parameter Modelica.Blocks.Types.Init initType=Modelica.Blocks.Types.Init.InitialState
          "Type of initialization (1: no init, 2: steady state, 3,4: initial output)"
                                                                                          annotation(Evaluate=true,
            Dialog(group="Initialization"));
        parameter Real y_start=0 "Initial or guess value of output (= state)"
          annotation (Dialog(group="Initialization"));
        extends Interfaces.SISO(y(start=y_start));

      initial equation
        if initType == Init.SteadyState then
           der(y) = 0;
        elseif initType == Init.InitialState or
               initType == Init.InitialOutput then
          y = y_start;
        end if;
      equation
        der(y) = k*u;
        annotation (
          Documentation(info="<html>
<p>
This blocks computes output <b>y</b> (element-wise) as
<i>integral</i> of the input <b>u</b> multiplied with
the gain <i>k</i>:
</p>
<pre>
         k
     y = - u
         s
</pre>

<p>
It might be difficult to initialize the integrator in steady state.
This is discussed in the description of package
<a href=\"modelica://Modelica.Blocks.Continuous#info\">Continuous</a>.
</p>

</html>
"),       Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics={
              Line(points={{-80,78},{-80,-90}}, color={192,192,192}),
              Polygon(
                points={{-80,90},{-88,68},{-72,68},{-80,90}},
                lineColor={192,192,192},
                fillColor={192,192,192},
                fillPattern=FillPattern.Solid),
              Line(points={{-90,-80},{82,-80}}, color={192,192,192}),
              Polygon(
                points={{90,-80},{68,-72},{68,-88},{90,-80}},
                lineColor={192,192,192},
                fillColor={192,192,192},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{0,-10},{60,-70}},
                lineColor={192,192,192},
                textString="I"),
              Text(
                extent={{-150,-150},{150,-110}},
                lineColor={0,0,0},
                textString="k=%k"),
              Line(points={{-80,-80},{80,80}}, color={0,0,127})}),
          Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics={
              Rectangle(extent={{-60,60},{60,-60}}, lineColor={0,0,255}),
              Line(points={{-100,0},{-60,0}}, color={0,0,255}),
              Line(points={{60,0},{100,0}}, color={0,0,255}),
              Text(
                extent={{-36,60},{32,2}},
                lineColor={0,0,0},
                textString="k"),
              Text(
                extent={{-32,0},{36,-58}},
                lineColor={0,0,0},
                textString="s"),
              Line(points={{-46,0},{46,0}}, color={0,0,0})}));
      end Integrator;
      annotation (
        Documentation(info="<html>
<p>
This package contains basic <b>continuous</b> input/output blocks
described by differential equations.
</p>

<p>
All blocks of this package can be initialized in different
ways controlled by parameter <b>initType</b>. The possible
values of initType are defined in
<a href=\"modelica://Modelica.Blocks.Types.Init\">Modelica.Blocks.Types.Init</a>:
</p>

<table border=1 cellspacing=0 cellpadding=2>
  <tr><td valign=\"top\"><b>Name</b></td>
      <td valign=\"top\"><b>Description</b></td></tr>

  <tr><td valign=\"top\"><b>Init.NoInit</b></td>
      <td valign=\"top\">no initialization (start values are used as guess values with fixed=false)</td></tr>

  <tr><td valign=\"top\"><b>Init.SteadyState</b></td>
      <td valign=\"top\">steady state initialization (derivatives of states are zero)</td></tr>

  <tr><td valign=\"top\"><b>Init.InitialState</b></td>
      <td valign=\"top\">Initialization with initial states</td></tr>

  <tr><td valign=\"top\"><b>Init.InitialOutput</b></td>
      <td valign=\"top\">Initialization with initial outputs (and steady state of the states if possibles)</td></tr>
</table>

<p>
For backward compatibility reasons the default of all blocks is
<b>Init.NoInit</b>, with the exception of Integrator and LimIntegrator
where the default is <b>Init.InitialState</b> (this was the initialization
defined in version 2.2 of the Modelica standard library).
</p>

<p>
In many cases, the most useful initial condition is
<b>Init.SteadyState</b> because initial transients are then no longer
present. The drawback is that in combination with a non-linear
plant, non-linear algebraic equations occur that might be
difficult to solve if appropriate guess values for the
iteration variables are not provided (i.e., start values with fixed=false).
However, it is often already useful to just initialize
the linear blocks from the Continuous blocks library in SteadyState.
This is uncritical, because only linear algebraic equations occur.
If Init.NoInit is set, then the start values for the states are
interpreted as <b>guess</b> values and are propagated to the
states with fixed=<b>false</b>.
</p>

<p>
Note, initialization with Init.SteadyState is usually difficult
for a block that contains an integrator
(Integrator, LimIntegrator, PI, PID, LimPID).
This is due to the basic equation of an integrator:
</p>

<pre>
  <b>initial equation</b>
     <b>der</b>(y) = 0;   // Init.SteadyState
  <b>equation</b>
     <b>der</b>(y) = k*u;
</pre>

<p>
The steady state equation leads to the condition that the input to the
integrator is zero. If the input u is already (directly or indirectly) defined
by another initial condition, then the initialization problem is <b>singular</b>
(has none or infinitely many solutions). This situation occurs often
for mechanical systems, where, e.g., u = desiredSpeed - measuredSpeed and
since speed is both a state and a derivative, it is always defined by
Init.InitialState or Init.SteadyState initializtion.
</p>

<p>
In such a case, <b>Init.NoInit</b> has to be selected for the integrator
and an additional initial equation has to be added to the system
to which the integrator is connected. E.g., useful initial conditions
for a 1-dim. rotational inertia controlled by a PI controller are that
<b>angle</b>, <b>speed</b>, and <b>acceleration</b> of the inertia are zero.
</p>

</html>
"));
    end Continuous;

    package Interfaces
      "Library of connectors and partial models for input/output blocks"
      import Modelica.SIunits;
        extends Modelica.Icons.InterfacesPackage;

    connector RealInput = input Real "'input Real' as connector"
      annotation (defaultComponentName="u",
      Icon(graphics={Polygon(
              points={{-100,100},{100,0},{-100,-100},{-100,100}},
              lineColor={0,0,127},
              fillColor={0,0,127},
              fillPattern=FillPattern.Solid)},
           coordinateSystem(extent={{-100,-100},{100,100}}, preserveAspectRatio=true, initialScale=0.2)),
      Diagram(coordinateSystem(
            preserveAspectRatio=true, initialScale=0.2,
            extent={{-100,-100},{100,100}},
            grid={1,1}), graphics={Polygon(
              points={{0,50},{100,0},{0,-50},{0,50}},
              lineColor={0,0,127},
              fillColor={0,0,127},
              fillPattern=FillPattern.Solid), Text(
              extent={{-10,85},{-10,60}},
              lineColor={0,0,127},
              textString="%name")}),
        Documentation(info="<html>
<p>
Connector with one input signal of type Real.
</p>
</html>"));

    connector RealOutput = output Real "'output Real' as connector"
      annotation (defaultComponentName="y",
      Icon(coordinateSystem(
            preserveAspectRatio=true,
            extent={{-100,-100},{100,100}},
            grid={1,1}), graphics={Polygon(
              points={{-100,100},{100,0},{-100,-100},{-100,100}},
              lineColor={0,0,127},
              fillColor={255,255,255},
              fillPattern=FillPattern.Solid)}),
      Diagram(coordinateSystem(
            preserveAspectRatio=true,
            extent={{-100,-100},{100,100}},
            grid={1,1}), graphics={Polygon(
              points={{-100,50},{0,0},{-100,-50},{-100,50}},
              lineColor={0,0,127},
              fillColor={255,255,255},
              fillPattern=FillPattern.Solid), Text(
              extent={{30,110},{30,60}},
              lineColor={0,0,127},
              textString="%name")}),
        Documentation(info="<html>
<p>
Connector with one output signal of type Real.
</p>
</html>"));

        partial block BlockIcon "Basic graphical layout of input/output block"

          annotation (
            Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{
                  100,100}}), graphics={Rectangle(
                extent={{-100,-100},{100,100}},
                lineColor={0,0,127},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid), Text(
                extent={{-150,150},{150,110}},
                textString="%name",
                lineColor={0,0,255})}),
          Documentation(info="<html>
<p>
Block that has only the basic icon for an input/output
block (no declarations, no equations). Most blocks
of package Modelica.Blocks inherit directly or indirectly
from this block.
</p>
</html>"));

        end BlockIcon;

        partial block SO "Single Output continuous control block"
          extends BlockIcon;

          RealOutput y "Connector of Real output signal"
            annotation (Placement(transformation(extent={{100,-10},{120,10}},
                rotation=0)));
          annotation (
            Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics),
          Documentation(info="<html>
<p>
Block has one continuous Real output signal.
</p>
</html>"));

        end SO;

        partial block SISO
        "Single Input Single Output continuous control block"
          extends BlockIcon;

          RealInput u "Connector of Real input signal"
            annotation (Placement(transformation(extent={{-140,-20},{-100,20}},
                rotation=0)));
          RealOutput y "Connector of Real output signal"
            annotation (Placement(transformation(extent={{100,-10},{120,10}},
                rotation=0)));
          annotation (
          Documentation(info="<html>
<p>
Block has one continuous Real input and one continuous Real output signal.
</p>
</html>"));
        end SISO;

        partial block SI2SO
        "2 Single Input / 1 Single Output continuous control block"
          extends BlockIcon;

          RealInput u1 "Connector of Real input signal 1"
            annotation (Placement(transformation(extent={{-140,40},{-100,80}},
                rotation=0)));
          RealInput u2 "Connector of Real input signal 2"
            annotation (Placement(transformation(extent={{-140,-80},{-100,-40}},
                rotation=0)));
          RealOutput y "Connector of Real output signal"
            annotation (Placement(transformation(extent={{100,-10},{120,10}},
                rotation=0)));

          annotation (
            Documentation(info="<html>
<p>
Block has two continuous Real input signals u1 and u2 and one
continuous Real output signal y.
</p>
</html>"),  Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics));

        end SI2SO;
        annotation (
          Documentation(info="<HTML>
<p>
This package contains interface definitions for
<b>continuous</b> input/output blocks with Real,
Integer and Boolean signals. Furthermore, it contains
partial models for continuous and discrete blocks.
</p>

</HTML>
",     revisions="<html>
<ul>
<li><i>Oct. 21, 2002</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>
       and <a href=\"http://www.robotic.dlr.de/Christian.Schweiger/\">Christian Schweiger</a>:<br>
       Added several new interfaces. <a href=\"modelica://Modelica/Documentation/ChangeNotes1.5.html\">Detailed description</a> available.
<li><i>Oct. 24, 1999</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       RealInputSignal renamed to RealInput. RealOutputSignal renamed to
       output RealOutput. GraphBlock renamed to BlockIcon. SISOreal renamed to
       SISO. SOreal renamed to SO. I2SOreal renamed to M2SO.
       SignalGenerator renamed to SignalSource. Introduced the following
       new models: MIMO, MIMOs, SVcontrol, MVcontrol, DiscreteBlockIcon,
       DiscreteBlock, DiscreteSISO, DiscreteMIMO, DiscreteMIMOs,
       BooleanBlockIcon, BooleanSISO, BooleanSignalSource, MI2BooleanMOs.</li>
<li><i>June 30, 1999</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       Realized a first version, based on an existing Dymola library
       of Dieter Moormann and Hilding Elmqvist.</li>
</ul>
</html>
"));
    end Interfaces;

    package Math
      "Library of Real mathematical functions as input/output blocks"
      import Modelica.SIunits;
      import Modelica.Blocks.Interfaces;
      extends Modelica.Icons.Package;

          block Add
        "Output the sum of the two inputs (this is an obsolet block. Use instead MultiSum)"
            extends Interfaces.SI2SO;
            parameter Real k1=+1 "Gain of upper input";
            parameter Real k2=+1 "Gain of lower input";

          equation
            y = k1*u1 + k2*u2;
            annotation (
              Documentation(info="
<HTML>
<p>
This blocks computes output <b>y</b> as <i>sum</i> of the
two input signals <b>u1</b> and <b>u2</b>:
</p>
<pre>
    <b>y</b> = k1*<b>u1</b> + k2*<b>u2</b>;
</pre>
<p>
Example:
</p>
<pre>
     parameter:   k1= +2, k2= -3

  results in the following equations:

     y = 2 * u1 - 3 * u2
</pre>

</HTML>
"),           Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics={
              Text(
                extent={{-98,-52},{7,-92}},
                lineColor={0,0,0},
                textString="%k2"),
              Text(
                extent={{-100,90},{5,50}},
                lineColor={0,0,0},
                textString="%k1"),
              Text(
                extent={{-150,150},{150,110}},
                textString="%name",
                lineColor={0,0,255}),
              Line(points={{-100,60},{-40,60},{-30,40}}, color={0,0,255}),
              Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,255}),
              Line(points={{-100,-60},{-40,-60},{-30,-40}}, color={0,0,255}),
              Line(points={{-15,-25.99},{15,25.99}}, color={0,0,0}),
              Rectangle(
                extent={{-100,-100},{100,100}},
                lineColor={0,0,127},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Line(points={{50,0},{100,0}}, color={0,0,255}),
              Line(points={{-100,60},{-74,24},{-44,24}}, color={0,0,127}),
              Line(points={{-100,-60},{-74,-28},{-42,-28}}, color={0,0,127}),
              Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,127}),
              Line(points={{50,0},{100,0}}, color={0,0,127}),
              Text(
                extent={{-38,34},{38,-34}},
                lineColor={0,0,0},
                textString="+"),
              Text(
                extent={{-100,52},{5,92}},
                lineColor={0,0,0},
                textString="%k1"),
              Text(
                extent={{-100,-52},{5,-92}},
                lineColor={0,0,0},
                textString="%k2")}),
              Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics={
              Rectangle(
                extent={{-100,-100},{100,100}},
                lineColor={0,0,255},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-98,-52},{7,-92}},
                lineColor={0,0,0},
                textString="%k2"),
              Text(
                extent={{-100,90},{5,50}},
                lineColor={0,0,0},
                textString="%k1"),
              Line(points={{-100,60},{-40,60},{-30,40}}, color={0,0,255}),
              Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,255}),
              Line(points={{-100,-60},{-40,-60},{-30,-40}}, color={0,0,255}),
              Line(points={{-15,-25.99},{15,25.99}}, color={0,0,0}),
              Rectangle(
                extent={{-100,-100},{100,100}},
                lineColor={0,0,127},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Line(points={{50,0},{100,0}}, color={0,0,255}),
              Line(points={{-100,60},{-74,24},{-44,24}}, color={0,0,127}),
              Line(points={{-100,-60},{-74,-28},{-42,-28}}, color={0,0,127}),
              Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,127}),
              Line(points={{50,0},{100,0}}, color={0,0,127}),
              Text(
                extent={{-38,34},{38,-34}},
                lineColor={0,0,0},
                textString="+"),
              Text(
                extent={{-100,52},{5,92}},
                lineColor={0,0,0},
                textString="k1"),
              Text(
                extent={{-100,-52},{5,-92}},
                lineColor={0,0,0},
                textString="k2")}));
          end Add;

          block Product
        "Output product of the two inputs (this is an obsolet block. Use instead MultiProduct)"
            extends Interfaces.SI2SO;

          equation
            y = u1*u2;
            annotation (
              Documentation(info="
<HTML>
<p>
This blocks computes the output <b>y</b> (element-wise)
as <i>product</i> of the corresponding elements of
the two inputs <b>u1</b> and <b>u2</b>:
</p>
<pre>
    y = u1 * u2;
</pre>

</HTML>
"),           Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics={
              Line(points={{-100,60},{-40,60},{-30,40}}, color={0,0,127}),
              Line(points={{-100,-60},{-40,-60},{-30,-40}}, color={0,0,127}),
              Line(points={{50,0},{100,0}}, color={0,0,127}),
              Line(points={{-30,0},{30,0}}, color={0,0,0}),
              Line(points={{-15,25.99},{15,-25.99}}, color={0,0,0}),
              Line(points={{-15,-25.99},{15,25.99}}, color={0,0,0}),
              Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,127})}),
              Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics={
              Rectangle(
                extent={{-100,-100},{100,100}},
                lineColor={0,0,255},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Line(points={{-100,60},{-40,60},{-30,40}}, color={0,0,255}),
              Line(points={{-100,-60},{-40,-60},{-30,-40}}, color={0,0,255}),
              Line(points={{50,0},{100,0}}, color={0,0,255}),
              Line(points={{-30,0},{30,0}}, color={0,0,0}),
              Line(points={{-15,25.99},{15,-25.99}}, color={0,0,0}),
              Line(points={{-15,-25.99},{15,25.99}}, color={0,0,0}),
              Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,255})}));
          end Product;

          block Division "Output first input divided by second input"
            extends Interfaces.SI2SO;

          equation
            y = u1/u2;
            annotation (
              Documentation(info="
<HTML>
<p>
This block computes the output <b>y</b> (element-wise)
by <i>dividing</i> the corresponding elements of
the two inputs <b>u1</b> and <b>u2</b>:
</p>
<pre>
    y = u1 / u2;
</pre>

</HTML>
"),           Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics={
              Line(points={{50,0},{100,0}}, color={0,0,127}),
              Line(points={{-30,0},{30,0}}, color={0,0,0}),
              Ellipse(
                extent={{-5,20},{5,30}},
                lineColor={0,0,0},
                fillColor={0,0,0},
                fillPattern=FillPattern.Solid),
              Ellipse(
                extent={{-5,-20},{5,-30}},
                lineColor={0,0,0},
                fillColor={0,0,0},
                fillPattern=FillPattern.Solid),
              Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,127}),
              Text(
                extent={{-150,150},{150,110}},
                textString="%name",
                lineColor={0,0,255}),
              Line(points={{-100,60},{-66,60},{-40,30}}, color={0,0,127}),
              Line(points={{-100,-60},{0,-60},{0,-50}}, color={0,0,127})}),
              Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics={
              Rectangle(
                extent={{-100,-100},{100,100}},
                lineColor={0,0,255},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Line(points={{50,0},{100,0}}, color={0,0,255}),
              Line(points={{-30,0},{30,0}}, color={0,0,0}),
              Ellipse(
                extent={{-5,20},{5,30}},
                lineColor={0,0,0},
                fillColor={0,0,0},
                fillPattern=FillPattern.Solid),
              Ellipse(
                extent={{-5,-20},{5,-30}},
                lineColor={0,0,0},
                fillColor={0,0,0},
                fillPattern=FillPattern.Solid),
              Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,255}),
              Line(points={{-100,60},{-66,60},{-40,30}}, color={0,0,255}),
              Line(points={{-100,-60},{0,-60},{0,-50}}, color={0,0,255})}));
          end Division;
      annotation (
        Documentation(info="
<HTML>
<p>
This package contains basic <b>mathematical operations</b>,
such as summation and multiplication, and basic <b>mathematical
functions</b>, such as <b>sqrt</b> and <b>sin</b>, as
input/output blocks. All blocks of this library can be either
connected with continuous blocks or with sampled-data blocks.
</p>
</HTML>
",     revisions="<html>
<ul>
<li><i>October 21, 2002</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>
       and <a href=\"http://www.robotic.dlr.de/Christian.Schweiger/\">Christian Schweiger</a>:<br>
       New blocks added: RealToInteger, IntegerToReal, Max, Min, Edge, BooleanChange, IntegerChange.</li>
<li><i>August 7, 1999</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       Realized (partly based on an existing Dymola library
       of Dieter Moormann and Hilding Elmqvist).
</li>
</ul>
</html>"));
    end Math;

    package Sources
      "Library of signal source blocks generating Real and Boolean signals"
      import Modelica.Blocks.Interfaces;
      import Modelica.SIunits;
      extends Modelica.Icons.SourcesPackage;

          block Constant "Generate constant signal of type Real"
            parameter Real k(start=1) "Constant output value";
            extends Interfaces.SO;

          equation
            y = k;
            annotation (defaultComponentName="const",
              Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics={
              Line(points={{-80,68},{-80,-80}}, color={192,192,192}),
              Polygon(
                points={{-80,90},{-88,68},{-72,68},{-80,90}},
                lineColor={192,192,192},
                fillColor={192,192,192},
                fillPattern=FillPattern.Solid),
              Line(points={{-90,-70},{82,-70}}, color={192,192,192}),
              Polygon(
                points={{90,-70},{68,-62},{68,-78},{90,-70}},
                lineColor={192,192,192},
                fillColor={192,192,192},
                fillPattern=FillPattern.Solid),
              Line(points={{-80,0},{80,0}}, color={0,0,0}),
              Text(
                extent={{-150,-150},{150,-110}},
                lineColor={0,0,0},
                textString="k=%k")}),
              Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics={
              Polygon(
                points={{-80,90},{-86,68},{-74,68},{-80,90}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Line(points={{-80,68},{-80,-80}}, color={95,95,95}),
              Line(
                points={{-80,0},{80,0}},
                color={0,0,255},
                thickness=0.5),
              Line(points={{-90,-70},{82,-70}}, color={95,95,95}),
              Polygon(
                points={{90,-70},{68,-64},{68,-76},{90,-70}},
                lineColor={95,95,95},
                fillColor={95,95,95},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-83,92},{-30,74}},
                lineColor={0,0,0},
                textString="y"),
              Text(
                extent={{70,-80},{94,-100}},
                lineColor={0,0,0},
                textString="time"),
              Text(
                extent={{-101,8},{-81,-12}},
                lineColor={0,0,0},
                textString="k")}),
          Documentation(info="<html>
<p>
The Real output y is a constant signal:
</p>

<p>
<img src=\"modelica://Modelica/Resources/Images/Blocks/Sources/Constant.png\">
</p>
</html>"));
          end Constant;
          annotation (
            Documentation(info="<HTML>
<p>
This package contains <b>source</b> components, i.e., blocks which
have only output signals. These blocks are used as signal generators
for Real, Integer and Boolean signals.
</p>

<p>
All Real source signals (with the exception of the Constant source)
have at least the following two parameters:
</p>

<table border=1 cellspacing=0 cellpadding=2>
  <tr><td valign=\"top\"><b>offset</b></td>
      <td valign=\"top\">Value which is added to the signal</td>
  </tr>
  <tr><td valign=\"top\"><b>startTime</b></td>
      <td valign=\"top\">Start time of signal. For time &lt; startTime,
                the output y is set to offset.</td>
  </tr>
</table>

<p>
The <b>offset</b> parameter is especially useful in order to shift
the corresponding source, such that at initial time the system
is stationary. To determine the corresponding value of offset,
usually requires a trimming calculation.
</p>
</HTML>
",     revisions="<html>
<ul>
<li><i>October 21, 2002</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>
       and <a href=\"http://www.robotic.dlr.de/Christian.Schweiger/\">Christian Schweiger</a>:<br>
       Integer sources added. Step, TimeTable and BooleanStep slightly changed.</li>
<li><i>Nov. 8, 1999</i>
       by <a href=\"mailto:clauss@eas.iis.fhg.de\">Christoph Clau&szlig;</a>,
       <a href=\"mailto:Andre.Schneider@eas.iis.fraunhofer.de\">Andre.Schneider@eas.iis.fraunhofer.de</a>,
       <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       New sources: Exponentials, TimeTable. Trapezoid slightly enhanced
       (nperiod=-1 is an infinite number of periods).</li>
<li><i>Oct. 31, 1999</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       <a href=\"mailto:clauss@eas.iis.fhg.de\">Christoph Clau&szlig;</a>,
       <a href=\"mailto:Andre.Schneider@eas.iis.fraunhofer.de\">Andre.Schneider@eas.iis.fraunhofer.de</a>,
       All sources vectorized. New sources: ExpSine, Trapezoid,
       BooleanConstant, BooleanStep, BooleanPulse, SampleTrigger.
       Improved documentation, especially detailed description of
       signals in diagram layer.</li>
<li><i>June 29, 1999</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       Realized a first version, based on an existing Dymola library
       of Dieter Moormann and Hilding Elmqvist.</li>
</ul>
</html>"));
    end Sources;

    package Types
      "Library of constants and types with choices, especially to build menus"
      extends Modelica.Icons.Package;

      type Init = enumeration(
          NoInit
            "No initialization (start values are used as guess values with fixed=false)",

          SteadyState
            "Steady state initialization (derivatives of states are zero)",
          InitialState "Initialization with initial states",
          InitialOutput
            "Initialization with initial outputs (and steady state of the states if possibles)")
        "Enumeration defining initialization of a block"
          annotation (Evaluate=true);

      annotation ( Documentation(info="<HTML>
<p>
In this package <b>types</b> and <b>constants</b> are defined that are used
in library Modelica.Blocks. The types have additional annotation choices
definitions that define the menus to be built up in the graphical
user interface when the type is used as parameter in a declaration.
</p>
</HTML>"));
    end Types;
  annotation (
    Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,100}}),
        graphics={
        Rectangle(extent={{-32,-6},{16,-35}}, lineColor={0,0,0}),
        Rectangle(extent={{-32,-56},{16,-85}}, lineColor={0,0,0}),
        Line(points={{16,-20},{49,-20},{49,-71},{16,-71}}, color={0,0,0}),
        Line(points={{-32,-72},{-64,-72},{-64,-21},{-32,-21}}, color={0,0,0}),
        Polygon(
          points={{16,-71},{29,-67},{29,-74},{16,-71}},
          lineColor={0,0,0},
          fillColor={0,0,0},
          fillPattern=FillPattern.Solid),
        Polygon(
          points={{-32,-21},{-46,-17},{-46,-25},{-32,-21}},
          lineColor={0,0,0},
          fillColor={0,0,0},
          fillPattern=FillPattern.Solid)}),
                            Documentation(info="<html>
<p>
This library contains input/output blocks to build up block diagrams.
</p>

<dl>
<dt><b>Main Author:</b>
<dd><a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a><br>
    Deutsches Zentrum f&uuml;r Luft und Raumfahrt e. V. (DLR)<br>
    Oberpfaffenhofen<br>
    Postfach 1116<br>
    D-82230 Wessling<br>
    email: <A HREF=\"mailto:Martin.Otter@dlr.de\">Martin.Otter@dlr.de</A><br>
</dl>
<p>
Copyright &copy; 1998-2010, Modelica Association and DLR.
</p>
<p>
<i>This Modelica package is <u>free</u> software and the use is completely at <u>your own risk</u>; it can be redistributed and/or modified under the terms of the Modelica License 2. For license conditions (including the disclaimer of warranty) see <a href=\"modelica://Modelica.UsersGuide.ModelicaLicense2\">Modelica.UsersGuide.ModelicaLicense2</a> or visit <a href=\"http://www.modelica.org/licenses/ModelicaLicense2\"> http://www.modelica.org/licenses/ModelicaLicense2</a>.</i>
</p>
</HTML>
",   revisions="<html>
<ul>
<li><i>June 23, 2004</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       Introduced new block connectors and adapated all blocks to the new connectors.
       Included subpackages Continuous, Discrete, Logical, Nonlinear from
       package ModelicaAdditions.Blocks.
       Included subpackage ModelicaAdditions.Table in Modelica.Blocks.Sources
       and in the new package Modelica.Blocks.Tables.
       Added new blocks to Blocks.Sources and Blocks.Logical.
       </li>
<li><i>October 21, 2002</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>
       and <a href=\"http://www.robotic.dlr.de/Christian.Schweiger/\">Christian Schweiger</a>:<br>
       New subpackage Examples, additional components.
       </li>
<li><i>June 20, 2000</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a> and
       Michael Tiller:<br>
       Introduced a replaceable signal type into
       Blocks.Interfaces.RealInput/RealOutput:
<pre>
   replaceable type SignalType = Real
</pre>
       in order that the type of the signal of an input/output block
       can be changed to a physical type, for example:
<pre>
   Sine sin1(outPort(redeclare type SignalType=Modelica.SIunits.Torque))
</pre>
      </li>
<li><i>Sept. 18, 1999</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       Renamed to Blocks. New subpackages Math, Nonlinear.
       Additional components in subpackages Interfaces, Continuous
       and Sources. </li>
<li><i>June 30, 1999</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       Realized a first version, based on an existing Dymola library
       of Dieter Moormann and Hilding Elmqvist.</li>
</ul>
</html>"));
  end Blocks;

  package Math
    "Library of mathematical functions (e.g., sin, cos) and of functions operating on vectors and matrices"
  import SI = Modelica.SIunits;
  extends Modelica.Icons.Package;

  function log10 "Base 10 logarithm (u shall be > 0)"
    extends baseIcon1;
    input Real u;
    output Real y;

  external "builtin" y=  log10(u);
    annotation (
      Icon(coordinateSystem(
          preserveAspectRatio=true,
          extent={{-100,-100},{100,100}},
          grid={2,2}), graphics={
          Line(points={{-90,0},{68,0}}, color={192,192,192}),
          Polygon(
            points={{90,0},{68,8},{68,-8},{90,0}},
            lineColor={192,192,192},
            fillColor={192,192,192},
            fillPattern=FillPattern.Solid),
          Line(points={{-79.8,-80},{-79.2,-50.6},{-78.4,-37},{-77.6,-28},{-76.8,-21.3},
                {-75.2,-11.4},{-72.8,-1.31},{-69.5,8.08},{-64.7,17.9},{-57.5,28},
                {-47,38.1},{-31.8,48.1},{-10.1,58},{22.1,68},{68.7,78.1},{80,80}},
              color={0,0,0}),
          Text(
            extent={{-30,-22},{60,-70}},
            lineColor={192,192,192},
            textString="log10")}),
      Diagram(coordinateSystem(
          preserveAspectRatio=true,
          extent={{-100,-100},{100,100}},
          grid={2,2}), graphics={
          Line(points={{-100,0},{84,0}}, color={95,95,95}),
          Polygon(
            points={{98,0},{82,6},{82,-6},{98,0}},
            lineColor={95,95,95},
            fillColor={95,95,95},
            fillPattern=FillPattern.Solid),
          Line(
            points={{-77.8,-80},{-77.2,-50.6},{-76.4,-37},{-75.6,-28},{-74.8,-21.3},
                {-73.2,-11.4},{-70.8,-1.31},{-67.5,8.08},{-62.7,17.9},{-55.5,28},
                {-45,38.1},{-29.8,48.1},{-8.1,58},{24.1,68},{70.7,78.1},{82,80}},
            color={0,0,255},
            thickness=0.5),
          Text(
            extent={{66,-13},{86,-33}},
            textString="20",
            lineColor={0,0,255}),
          Text(
            extent={{-78,-1},{-58,-21}},
            textString="1",
            lineColor={0,0,255}),
          Text(
            extent={{-83,62},{-63,78}},
            textString=" 1.3",
            lineColor={0,0,255}),
          Text(
            extent={{80,24},{100,4}},
            lineColor={95,95,95},
            textString="u"),
          Text(
            extent={{-100,9},{-80,-11}},
            textString="0",
            lineColor={0,0,255}),
          Line(
            points={{-80,80},{86,80}},
            color={175,175,175},
            smooth=Smooth.None),
          Line(
            points={{80,92},{80,-12}},
            color={175,175,175},
            smooth=Smooth.None)}),
      Documentation(info="<html>
<p>
This function returns y = log10(u),
with u &gt; 0:
</p>

<p>
<img src=\"modelica://Modelica/Resources/Images/Math/log10.png\">
</p>
</html>"),   Library="ModelicaExternalC");
  end log10;

  partial function baseIcon1
      "Basic icon for mathematical function with y-axis on left side"

    annotation (Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,
              -100},{100,100}}), graphics={
          Rectangle(
            extent={{-100,100},{100,-100}},
            lineColor={0,0,0},
            fillColor={255,255,255},
            fillPattern=FillPattern.Solid),
          Line(points={{-80,-80},{-80,68}}, color={192,192,192}),
          Polygon(
            points={{-80,90},{-88,68},{-72,68},{-80,90}},
            lineColor={192,192,192},
            fillColor={192,192,192},
            fillPattern=FillPattern.Solid),
          Text(
            extent={{-150,150},{150,110}},
            textString="%name",
            lineColor={0,0,255})}),                          Diagram(
          coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,
              100}}), graphics={
          Line(points={{-80,80},{-88,80}}, color={95,95,95}),
          Line(points={{-80,-80},{-88,-80}}, color={95,95,95}),
          Line(points={{-80,-90},{-80,84}}, color={95,95,95}),
          Text(
            extent={{-75,104},{-55,84}},
            lineColor={95,95,95},
            textString="y"),
          Polygon(
            points={{-80,98},{-86,82},{-74,82},{-80,98}},
            lineColor={95,95,95},
            fillColor={95,95,95},
            fillPattern=FillPattern.Solid)}),
      Documentation(info="<html>
<p>
Icon for a mathematical function, consisting of an y-axis on the left side.
It is expected, that an x-axis is added and a plot of the function.
</p>
</html>"));
  end baseIcon1;
  annotation (
    Invisible=true,
    Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,100}}),
        graphics={Text(
          extent={{-59,-9},{42,-56}},
          lineColor={0,0,0},
          textString="f(x)")}),
    Documentation(info="<HTML>
<p>
This package contains <b>basic mathematical functions</b> (such as sin(..)),
as well as functions operating on
<a href=\"modelica://Modelica.Math.Vectors\">vectors</a>,
<a href=\"modelica://Modelica.Math.Matrices\">matrices</a>,
<a href=\"modelica://Modelica.Math.Nonlinear\">nonlinear functions</a>, and
<a href=\"modelica://Modelica.Math.BooleanVectors\">Boolean vectors</a>.
</p>

<dl>
<dt><b>Main Authors:</b>
<dd><a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a> and
    Marcus Baur<br>
    Deutsches Zentrum f&uuml;r Luft und Raumfahrt e.V. (DLR)<br>
    Institut f&uuml;r Robotik und Mechatronik<br>
    Postfach 1116<br>
    D-82230 Wessling<br>
    Germany<br>
    email: <A HREF=\"mailto:Martin.Otter@dlr.de\">Martin.Otter@dlr.de</A><br>
</dl>

<p>
Copyright &copy; 1998-2010, Modelica Association and DLR.
</p>
<p>
<i>This Modelica package is <u>free</u> software and the use is completely at <u>your own risk</u>; it can be redistributed and/or modified under the terms of the Modelica License 2. For license conditions (including the disclaimer of warranty) see <a href=\"modelica://Modelica.UsersGuide.ModelicaLicense2\">Modelica.UsersGuide.ModelicaLicense2</a> or visit <a href=\"http://www.modelica.org/licenses/ModelicaLicense2\"> http://www.modelica.org/licenses/ModelicaLicense2</a>.</i>
</p>
</HTML>
",   revisions="<html>
<ul>
<li><i>October 21, 2002</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>
       and <a href=\"http://www.robotic.dlr.de/Christian.Schweiger/\">Christian Schweiger</a>:<br>
       Function tempInterpol2 added.</li>
<li><i>Oct. 24, 1999</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       Icons for icon and diagram level introduced.</li>
<li><i>June 30, 1999</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       Realized.</li>
</ul>

</html>"));
  end Math;

  package Icons "Library of icons"
    extends Icons.Package;

    partial package Package "Icon for standard packages"

      annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                -100},{100,100}}), graphics={Rectangle(
              extent={{-80,100},{100,-80}},
              lineColor={0,0,0},
              fillColor={215,230,240},
              fillPattern=FillPattern.Solid), Rectangle(
              extent={{-100,80},{80,-100}},
              lineColor={0,0,0},
              fillColor={240,240,240},
              fillPattern=FillPattern.Solid)}),
                                Documentation(info="<html>
<p>Standard package icon.</p>
</html>"));
    end Package;

    partial package InterfacesPackage "Icon for packages containing interfaces"
    //extends Modelica.Icons.Package;
      annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                -100},{100,100}}), graphics={Rectangle(
              extent={{-80,100},{100,-80}},
              lineColor={0,0,0},
              fillColor={215,230,240},
              fillPattern=FillPattern.Solid), Rectangle(
              extent={{-100,80},{80,-100}},
              lineColor={0,0,0},
              fillColor={240,240,240},
              fillPattern=FillPattern.Solid),
            Polygon(
              points={{0,50},{20,50},{50,10},{80,10},{80,-30},{50,-30},{20,-70},{
                  0,-70},{0,50}},
              lineColor={0,0,0},
              smooth=Smooth.None,
              fillColor={215,215,215},
              fillPattern=FillPattern.Solid),
            Polygon(
              points={{-100,10},{-70,10},{-40,50},{-20,50},{-20,-70},{-40,-70},{
                  -70,-30},{-100,-30},{-100,10}},
              lineColor={0,0,0},
              smooth=Smooth.None,
              fillColor={215,230,240},
              fillPattern=FillPattern.Solid)}),
                                Documentation(info="<html>
<p>This icon indicates packages containing interfaces.</p>
</html>"));
    end InterfacesPackage;

    partial package SourcesPackage "Icon for packages containing sources"
    //extends Modelica.Icons.Package;
      annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                -100},{100,100}}), graphics={Rectangle(
              extent={{-80,100},{100,-80}},
              lineColor={0,0,0},
              fillColor={215,230,240},
              fillPattern=FillPattern.Solid), Rectangle(
              extent={{-100,80},{80,-100}},
              lineColor={0,0,0},
              fillColor={240,240,240},
              fillPattern=FillPattern.Solid),
            Polygon(
              points={{-28,12},{-28,-40},{36,-14},{-28,12}},
              lineColor={0,0,0},
              smooth=Smooth.None,
              fillColor={255,255,255},
              fillPattern=FillPattern.Solid),
            Line(
              points={{-28,-14},{-68,-14}},
              color={0,0,0},
              smooth=Smooth.None)}),
                                Documentation(info="<html>
<p>This icon indicates a package which contains sources.</p>
</html>"));
    end SourcesPackage;
    annotation(Documentation(__Dymola_DocumentationClass=true, info="<html>
<p>This package contains definitions for the graphical layout of components which may be used in different libraries. The icons can be utilized by inheriting them in the desired class using &quot;extends&quot; or by directly copying the &quot;icon&quot; layer. </p>
<dl>
<dt><b>Main Authors:</b> </dt>
    <dd><a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a></dd><dd>Deutsches Zentrum fuer Luft und Raumfahrt e.V. (DLR)</dd><dd>Oberpfaffenhofen</dd><dd>Postfach 1116</dd><dd>D-82230 Wessling</dd><dd>email: <a href=\"mailto:Martin.Otter@dlr.de\">Martin.Otter@dlr.de</a></dd><br>
    <dd>Christian Kral</dd><dd><a href=\"http://www.ait.ac.at/\">Austrian Institute of Technology, AIT</a></dd><dd>Mobility Department</dd><dd>Giefinggasse 2</dd><dd>1210 Vienna, Austria</dd><dd>email: <a href=\"mailto:christian.kral@ait.ac.at\">christian.kral@ait.ac.at</a></dd><br>
    <dd align=\"justify\">Johan Andreasson</dd><dd align=\"justify\"><a href=\"http://www.modelon.se/\">Modelon AB</a></dd><dd align=\"justify\">Ideon Science Park</dd><dd align=\"justify\">22370 Lund, Sweden</dd><dd align=\"justify\">email: <a href=\"mailto:johan.andreasson@modelon.se\">johan.andreasson@modelon.se</a></dd>
</dl>
<p>Copyright &copy; 1998-2010, Modelica Association, DLR, AIT, and Modelon AB. </p>
<p><i>This Modelica package is <b>free</b> software; it can be redistributed and/or modified under the terms of the <b>Modelica license</b>, see the license conditions and the accompanying <b>disclaimer</b> in <a href=\"modelica://Modelica.UsersGuide.ModelicaLicense2\">Modelica.UsersGuide.ModelicaLicense2</a>.</i> </p>
</html>"));
  end Icons;

  package SIunits
    "Library of type and unit definitions based on SI units according to ISO 31-1992"
    extends Modelica.Icons.Package;
    annotation (
      Invisible=true,
      Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,
              100}}), graphics={Text(
            extent={{-63,-13},{45,-67}},
            lineColor={0,0,0},
            textString="[kg.m2]")}),
      Documentation(info="<html>
<p>This package provides predefined types, such as <i>Mass</i>,
<i>Angle</i>, <i>Time</i>, based on the international standard
on units, e.g.,
</p>

<pre>   <b>type</b> Angle = Real(<b>final</b> quantity = \"Angle\",
                     <b>final</b> unit     = \"rad\",
                     displayUnit    = \"deg\");
</pre>

<p>
as well as conversion functions from non SI-units to SI-units
and vice versa in subpackage
<a href=\"modelica://Modelica.SIunits.Conversions\">Conversions</a>.
</p>

<p>
For an introduction how units are used in the Modelica standard library
with package SIunits, have a look at:
<a href=\"modelica://Modelica.SIunits.UsersGuide.HowToUseSIunits\">How to use SIunits</a>.
</p>

<p>
Copyright &copy; 1998-2010, Modelica Association and DLR.
</p>
<p>
<i>This Modelica package is <u>free</u> software and the use is completely at <u>your own risk</u>; it can be redistributed and/or modified under the terms of the Modelica License 2. For license conditions (including the disclaimer of warranty) see <a href=\"modelica://Modelica.UsersGuide.ModelicaLicense2\">Modelica.UsersGuide.ModelicaLicense2</a> or visit <a href=\"http://www.modelica.org/licenses/ModelicaLicense2\"> http://www.modelica.org/licenses/ModelicaLicense2</a>.</i>
</p>
</html>",   revisions="<html>
<ul>
<li><i>Jan. 27, 2010</i> by Christian Kral:<br/>Added complex units.</li>
<li><i>Dec. 14, 2005</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br/>Add User&#39;;s Guide and removed &quot;min&quot; values for Resistance and Conductance.</li>
<li><i>October 21, 2002</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a> and <a href=\"http://www.robotic.dlr.de/Christian.Schweiger/\">Christian Schweiger</a>:<br/>Added new package <b>Conversions</b>. Corrected typo <i>Wavelenght</i>.</li>
<li><i>June 6, 2000</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br/>Introduced the following new types<br/>type Temperature = ThermodynamicTemperature;<br/>types DerDensityByEnthalpy, DerDensityByPressure, DerDensityByTemperature, DerEnthalpyByPressure, DerEnergyByDensity, DerEnergyByPressure<br/>Attribute &quot;final&quot; removed from min and max values in order that these values can still be changed to narrow the allowed range of values.<br/>Quantity=&quot;Stress&quot; removed from type &quot;Stress&quot;, in order that a type &quot;Stress&quot; can be connected to a type &quot;Pressure&quot;.</li>
<li><i>Oct. 27, 1999</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br/>New types due to electrical library: Transconductance, InversePotential, Damping.</li>
<li><i>Sept. 18, 1999</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br/>Renamed from SIunit to SIunits. Subpackages expanded, i.e., the SIunits package, does no longer contain subpackages.</li>
<li><i>Aug 12, 1999</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br/>Type &quot;Pressure&quot; renamed to &quot;AbsolutePressure&quot; and introduced a new type &quot;Pressure&quot; which does not contain a minimum of zero in order to allow convenient handling of relative pressure. Redefined BulkModulus as an alias to AbsolutePressure instead of Stress, since needed in hydraulics.</li>
<li><i>June 29, 1999</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br/>Bug-fix: Double definition of &quot;Compressibility&quot; removed and appropriate &quot;extends Heat&quot; clause introduced in package SolidStatePhysics to incorporate ThermodynamicTemperature.</li>
<li><i>April 8, 1998</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a> and Astrid Jaschinski:<br/>Complete ISO 31 chapters realized.</li>
<li><i>Nov. 15, 1997</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a> and <a href=\"http://www.control.lth.se/~hubertus/\">Hubertus Tummescheit</a>:<br/>Some chapters realized.</li>
</ul>
</html>"),
      Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,
              100}}), graphics={
          Rectangle(
            extent={{169,86},{349,236}},
            fillColor={235,235,235},
            fillPattern=FillPattern.Solid,
            lineColor={0,0,255}),
          Polygon(
            points={{169,236},{189,256},{369,256},{349,236},{169,236}},
            fillColor={235,235,235},
            fillPattern=FillPattern.Solid,
            lineColor={0,0,255}),
          Polygon(
            points={{369,256},{369,106},{349,86},{349,236},{369,256}},
            fillColor={235,235,235},
            fillPattern=FillPattern.Solid,
            lineColor={0,0,255}),
          Text(
            extent={{179,226},{339,196}},
            lineColor={160,160,164},
            textString="Library"),
          Text(
            extent={{206,173},{314,119}},
            lineColor={0,0,0},
            textString="[kg.m2]"),
          Text(
            extent={{163,320},{406,264}},
            lineColor={255,0,0},
            textString="Modelica.SIunits")}));
  end SIunits;
annotation (
preferredView="info",
version="3.2",
versionBuild=8,
versionDate="2010-10-25",
dateModified = "2011-09-05 15:20:00Z",
revisionId="",
uses(Complex(version="1.0"), ModelicaServices(version="1.2")),
conversion(
 noneFromVersion="3.1",
 noneFromVersion="3.0.1",
 noneFromVersion="3.0",
 from(version="2.1", script="modelica://Modelica/Resources/Scripts/Dymola/ConvertModelica_from_2.2.2_to_3.0.mos"),
 from(version="2.2", script="modelica://Modelica/Resources/Scripts/Dymola/ConvertModelica_from_2.2.2_to_3.0.mos"),
 from(version="2.2.1", script="modelica://Modelica/Resources/Scripts/Dymola/ConvertModelica_from_2.2.2_to_3.0.mos"),
 from(version="2.2.2", script="modelica://Modelica/Resources/Scripts/Dymola/ConvertModelica_from_2.2.2_to_3.0.mos")),
__Dymola_classOrder={"UsersGuide","Blocks","StateGraph","Electrical","Magnetic","Mechanics","Fluid","Media","Thermal",
      "Math","Utilities","Constants", "Icons", "SIunits"},
Settings(NewStateSelection=true),
Documentation(info="<HTML>
<p>
Package <b>Modelica&reg;</b> is a <b>standardized</b> and <b>free</b> package
that is developed together with the Modelica&reg; language from the
Modelica Association, see
<a href=\"http://www.Modelica.org\">http://www.Modelica.org</a>.
It is also called <b>Modelica Standard Library</b>.
It provides model components in many domains that are based on
standardized interface definitions. Some typical examples are shown
in the next figure:
</p>

<img src=\"modelica://Modelica/Resources/Images/UsersGuide/ModelicaLibraries.png\">

<p>
For an introduction, have especially a look at:
</p>
<ul>
<li> <a href=\"modelica://Modelica.UsersGuide.Overview\">Overview</a>
  provides an overview of the Modelica Standard Library
  inside the <a href=\"modelica://Modelica.UsersGuide\">User's Guide</a>.</li>
<li><a href=\"modelica://Modelica.UsersGuide.ReleaseNotes\">Release Notes</a>
 summarizes the changes of new versions of this package.</li>
<li> <a href=\"modelica://Modelica.UsersGuide.Contact\">Contact</a>
  lists the contributors of the Modelica Standard Library.</li>
<li> The <b>Examples</b> packages in the various libraries, demonstrate
  how to use the components of the corresponding sublibrary.</li>
</ul>

<p>
This version of the Modelica Standard Library consists of
</p>
<ul>
<li> <b>1280</b> models and blocks, and</li>
<li> <b>910</b> functions
</ul>
<p>
that are directly usable (= number of public, non-partial classes).
</p>

<p>
<b>Licensed by the Modelica Association under the Modelica License 2</b><br>
Copyright &copy; 1998-2010, ABB, AIT, T.&nbsp;B&ouml;drich, DLR, Dassault Syst&egrave;mes AB, Fraunhofer, A.Haumer, Modelon,
TU Hamburg-Harburg, Politecnico di Milano.
</p>

<p>
<i>This Modelica package is <u>free</u> software and the use is completely at <u>your own risk</u>; it can be redistributed and/or modified under the terms of the Modelica License 2. For license conditions (including the disclaimer of warranty) see <a href=\"modelica://Modelica.UsersGuide.ModelicaLicense2\">Modelica.UsersGuide.ModelicaLicense2</a> or visit <a href=\"http://www.modelica.org/licenses/ModelicaLicense2\"> http://www.modelica.org/licenses/ModelicaLicense2</a>.</i>
</p>
</HTML>
"));
end Modelica;


package IKEDA

  package Library

    block Constant

      Modelica.Blocks.Interfaces.RealOutput y annotation (Placement(transformation(
              extent={{-30,12},{-10,32}}), iconTransformation(extent={{96,-64},{226,
                66}})));
    parameter Real Const;
    equation
      y=Const;
      annotation (Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,
                -100},{100,100}},
            initialScale=0.04), graphics={Rectangle(
              extent={{-100,100},{100,-100}},
              lineColor={0,0,255},
              lineThickness=0.5), Text(
              extent={{-136,-12},{122,-58}},
              lineColor={0,0,255},
              lineThickness=0.5,
              textString="%Const"),
                                  Text(
              extent={{-136,76},{122,30}},
              lineColor={0,0,255},
              lineThickness=0.5,
              textString="%name")}),  Diagram(coordinateSystem(
            preserveAspectRatio=true,
            extent={{-100,-100},{100,100}},
            initialScale=0.04)));
    end Constant;

    package Interfaces

      connector RealInput = input Real "'input Real' as connector"
        annotation (defaultComponentName="u",
        Icon(graphics={Polygon(
              points={{-100,100},{100,0},{-100,-100},{-100,100}},
              lineColor={0,0,127},
              fillColor={0,0,127},
              fillPattern=FillPattern.Solid), Text(
              extent={{98,-98},{710,120}},
              lineColor={0,0,127},
              textString="%name")},
             coordinateSystem(extent={{-100,-100},{100,100}}, preserveAspectRatio=true, initialScale=0.2)),
        Diagram(coordinateSystem(
              preserveAspectRatio=true, initialScale=0.2,
              extent={{-100,-100},{100,100}},
              grid={1,1}), graphics={Polygon(
              points={{0,50},{100,0},{0,-50},{0,50}},
              lineColor={0,0,127},
              fillColor={0,0,127},
              fillPattern=FillPattern.Solid), Text(
              extent={{-10,85},{-10,60}},
              lineColor={0,0,127},
              textString="%name")}),
          Documentation(info="<html>
<p>
Connector with one input signal of type Real.
</p>
</html>"));

      connector RealOutput = output Real "'output Real' as connector"
        annotation (defaultComponentName="u",
        Icon(graphics={Polygon(
              points={{-100,100},{100,0},{-100,-100},{-100,100}},
              lineColor={0,0,127},
              fillColor={255,255,255},
              fillPattern=FillPattern.Solid), Text(
              extent={{-700,-118},{-100,100}},
              lineColor={0,0,127},
              textString="%name")},
             coordinateSystem(extent={{-100,-100},{100,100}}, preserveAspectRatio=true, initialScale=0.2)),
        Diagram(coordinateSystem(
              preserveAspectRatio=true, initialScale=0.2,
              extent={{-100,-100},{100,100}},
              grid={1,1}), graphics={Polygon(
              points={{0,50},{100,0},{0,-50},{0,50}},
              lineColor={0,0,127},
              fillColor={255,255,255},
              fillPattern=FillPattern.Solid), Text(
              extent={{-10,85},{-10,60}},
              lineColor={0,0,127},
              textString="%name")}),
          Documentation(info="<html>
<p>
Connector with one input signal of type Real.
</p>
</html>"));
    end Interfaces;
  end Library;

  model RenalAcidification

    Modelica.Blocks.Interfaces.RealInput YORG
      "renal excration rate of organic acid [mmol/min]"
                                              annotation (Placement(
          transformation(extent={{-110,-12},{-70,28}}),iconTransformation(
            extent={{-104,19},{-86,37}})));
    Modelica.Blocks.Interfaces.RealInput YPO4
      "renal excration rate of phosphate [mmol/min]"
                                              annotation (Placement(
          transformation(extent={{-110,-44},{-70,-4}}),iconTransformation(
            extent={{-104,-7},{-86,11}})));
    Modelica.Blocks.Interfaces.RealInput PHA "pH of arterial blood"
                                             annotation (Placement(
          transformation(extent={{-108,11},{-68,51}}),  iconTransformation(
            extent={{-104,-33},{-86,-15}})));
    Modelica.Blocks.Interfaces.RealInput Ald(unit="1") "effect of aldosterone"
                                             annotation (Placement(
          transformation(extent={{-108,-84},{-68,-44}}), iconTransformation(
            extent={{-104,-57},{-86,-39}})));
    Modelica.Blocks.Interfaces.RealOutput YTA
      "renal excration rate of titratable acid(default=0.0168) [mEq/min]"
                                              annotation (Placement(
          transformation(extent={{84,62},{104,82}}), iconTransformation(extent={{90,31},
              {108,49}})));
    Modelica.Blocks.Interfaces.RealOutput YNH4
      "renal excration rate of ammonium(default=0.024) [mEq/min]"
                                               annotation (Placement(
          transformation(extent={{84,38},{104,58}}), iconTransformation(extent={{92,3},{
              110,21}})));
    Modelica.Blocks.Interfaces.RealOutput PHU( start=6.0)
      "pH of urine (defautl=6)"               annotation (Placement(
          transformation(extent={{82,-40},{102,-20}}), iconTransformation(
            extent={{92,-33},{110,-15}})));
    RenalDistalAcidification renalDistalAcidification
      annotation (Placement(transformation(extent={{-42,8},{56,106}})));
    Modelica.Blocks.Math.Product product
      annotation (Placement(transformation(extent={{-38,-84},{-24,-70}})));
    Modelica.Blocks.Math.Add add
      annotation (Placement(transformation(extent={{6,-88},{18,-76}})));
    Modelica.Blocks.Math.Add add1
      annotation (Placement(transformation(extent={{64,66},{76,78}})));
    Modelica.Blocks.Interfaces.RealOutput YTA1 annotation (Placement(
          transformation(extent={{84,80},{104,100}}), iconTransformation(extent={{92,67},
              {110,85}})));
    IKEDA.PHUCalculation pHUCaculation
      annotation (Placement(transformation(extent={{-38,-73},{44,9}})));
    Modelica.Blocks.Interfaces.RealInput YNH40
      "Normal value of NH4 excretion [mEq/min]"
                                              annotation (Placement(
          transformation(extent={{-116,64},{-76,104}}),iconTransformation(
            extent={{-104,45},{-86,63}})));
    Modelica.Blocks.Interfaces.RealInput YTA0
      "Normal value of titratable acids excretio [mEq/min]n"
                                              annotation (Placement(
          transformation(extent={{-106,34},{-66,74}}), iconTransformation(
            extent={{-106,71},{-88,89}})));
    Library.Constant TPHU1(Const=300)
      annotation (Placement(transformation(extent={{-68,86},{-54,100}})));
    Library.Constant K1(Const=0.001)
      annotation (Placement(transformation(extent={{-82,-94},{-68,-80}})));
    Library.Constant K2(Const=0.009)
      annotation (Placement(transformation(extent={{-30,-100},{-16,-86}})));
    Library.Constant TPHA1(Const=200)
      annotation (Placement(transformation(extent={{-66,68},{-52,82}})));
  equation
    connect(Ald, product.u1) annotation (Line(
        points={{-88,-64},{-44,-64},{-44,-72.8},{-39.4,-72.8}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product.y, add.u1) annotation (Line(
        points={{-23.3,-77},{-9.65,-77},{-9.65,-78.4},{4.8,-78.4}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(YTA, YTA) annotation (Line(
        points={{94,72},{94,72}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(renalDistalAcidification.YTA1, add1.u1) annotation (Line(
        points={{47.67,81.5},{55.005,81.5},{55.005,75.6},{62.8,75.6}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(add1.y, YTA) annotation (Line(
        points={{76.6,72},{94,72}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(add.y, add1.u2) annotation (Line(
        points={{18.6,-82},{60,-82},{60,68.4},{62.8,68.4}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(renalDistalAcidification.YNH4, YNH4) annotation (Line(
        points={{48.65,63.86},{64.475,63.86},{64.475,48},{94,48}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(renalDistalAcidification.PHA, PHA) annotation (Line(
        points={{-32.69,39.36},{-52.535,39.36},{-52.535,31},{-88,31}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(YTA1, renalDistalAcidification.YTA1) annotation (Line(
        points={{94,90},{56,90},{56,81.5},{47.67,81.5}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pHUCaculation.YTA, add1.y) annotation (Line(
        points={{-28.16,-29.54},{-44,-29.54},{-44,14},{80,14},{80,72},{76.6,72}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

    connect(YPO4, pHUCaculation.YPO4) annotation (Line(
        points={{-90,-24},{-60,-24},{-60,6},{-8.07,6},{-8.07,-3.71}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(YORG, pHUCaculation.YORG) annotation (Line(
        points={{-90,8},{19.81,8},{19.81,-2.89}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pHUCaculation.PHA, PHA) annotation (Line(
        points={{8.74,-50.86},{8.74,-60},{-66,-60},{-66,31},{-88,31}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pHUCaculation.PHU, PHU) annotation (Line(
        points={{38.26,-29.54},{60.13,-29.54},{60.13,-30},{92,-30}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(renalDistalAcidification.PHU, PHU) annotation (Line(
        points={{-32.69,24.66},{-56,24.66},{-56,16},{74,16},{74,-30},{92,-30}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

    connect(PHU, PHU) annotation (Line(
        points={{92,-30},{92,-30}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(K2.y, add.u2) annotation (Line(
        points={{-11.73,-92.93},{0,-92.93},{0,-85.6},{4.8,-85.6}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(K1.y, product.u2) annotation (Line(
        points={{-63.73,-86.93},{-48,-86.93},{-48,-81.2},{-39.4,-81.2}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(renalDistalAcidification.YNH40, YNH40) annotation (Line(
        points={{-32.69,65.82},{-70,65.82},{-70,84},{-96,84}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(TPHA1.y, renalDistalAcidification.TPHA1) annotation (Line(
        points={{-47.73,75.07},{-40.865,75.07},{-40.865,77.58},{-32.69,77.58}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

    connect(TPHU1.y, renalDistalAcidification.TPHU1) annotation (Line(
        points={{-49.73,93.07},{-42.865,93.07},{-42.865,89.34},{-32.69,89.34}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

    connect(YTA0, renalDistalAcidification.YTA0) annotation (Line(
        points={{-86,54},{-59.345,54},{-59.345,53.08},{-32.69,53.08}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    annotation (Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
              -100},{100,100}}), graphics={Text(
            extent={{6,-80},{74,-76}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YTA=0.001*Ald+0.009+YTA1")}), Icon(coordinateSystem(
            preserveAspectRatio=true, extent={{-100,-100},{100,100}}), graphics={
          Rectangle(
            extent={{-100,100},{100,-100}},
            lineColor={0,0,255},
            lineThickness=0.5),
          Text(
            extent={{98,-96},{-96,-60}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="acidification"),
          Text(
            extent={{-92,20},{-32,36}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YORG"),
          Text(
            extent={{-94,-6},{-36,10}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YPO4"),
          Text(
            extent={{-90,-30},{-40,-14}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="PHA"),
          Text(
            extent={{-94,-58},{-38,-40}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="Ald"),
          Text(
            extent={{34,34},{100,48}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YTA"),
          Text(
            extent={{22,4},{100,20}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YNH4"),
          Text(
            extent={{34,-30},{100,-16}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="PHU"),
          Text(
            extent={{30,68},{100,84}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YTA1"),
          Text(
            extent={{60,-64},{-50,-28}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="Renal"),
          Text(
            extent={{-92,46},{-32,62}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YNH40"),
          Text(
            extent={{-94,72},{-34,88}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YTA0")}));
  end RenalAcidification;

  model RenalDistalAcidification

    Modelica.Blocks.Interfaces.RealInput TPHU1 annotation (Placement(
          transformation(extent={{-102,-98},{-82,-78}}),
                                                      iconTransformation(extent={{
              -90,57},{-72,75}})));
    Modelica.Blocks.Interfaces.RealInput YNH40 annotation (Placement(
          transformation(extent={{-104,-38},{-84,-18}}),iconTransformation(extent={{-90,9},
              {-72,27}})));
    Modelica.Blocks.Interfaces.RealInput YTA0 annotation (Placement(
          transformation(extent={{-100,66},{-80,86}}),  iconTransformation(extent={{-90,-17},
              {-72,1}})));
    Modelica.Blocks.Interfaces.RealInput TPHA1 annotation (Placement(
          transformation(extent={{-100,13},{-82,31}}),  iconTransformation(extent={{-90,33},
              {-72,51}})));
    Modelica.Blocks.Interfaces.RealInput PHA annotation (Placement(transformation(
            extent={{-108,32},{-76,64}}),   iconTransformation(extent={{-90,-45},
              {-72,-27}})));
    Modelica.Blocks.Interfaces.RealInput PHU annotation (Placement(transformation(
            extent={{-110,-70},{-76,-36}}),  iconTransformation(extent={{-90,-75},
              {-72,-57}})));
    Modelica.Blocks.Interfaces.RealOutput YTA1 annotation (Placement(
          transformation(extent={{90,28},{110,48}}),iconTransformation(extent={{74,
              41},{92,59}})));
    Modelica.Blocks.Interfaces.RealOutput YNH4 annotation (Placement(
          transformation(extent={{72,-60},{92,-40}}),
                                                    iconTransformation(extent={{76,
              5},{94,23}})));

    Modelica.Blocks.Continuous.Integrator integrator(y_start=6.0, k=1)
      annotation (Placement(transformation(extent={{-26,-78},{-12,-64}})));
    Modelica.Blocks.Math.Add add(k2=-1)
      annotation (Placement(transformation(extent={{-66,-78},{-52,-64}})));
    Modelica.Blocks.Math.Product product
      annotation (Placement(transformation(extent={{12,-72},{24,-60}})));
    Modelica.Blocks.Math.Division division
      annotation (Placement(transformation(extent={{-44,-76},{-34,-66}})));
    Modelica.Blocks.Sources.Constant const(k=-0.5)
      annotation (Placement(transformation(extent={{-6,-60},{2,-52}})));
    Modelica.Blocks.Math.Add add1(k2=+1)
      annotation (Placement(transformation(extent={{33,-61},{47,-47}})));
    Modelica.Blocks.Sources.Constant const1(k=4)
      annotation (Placement(transformation(extent={{13,-53},{21,-45}})));
    Modelica.Blocks.Math.Product product1
      annotation (Placement(transformation(extent={{56,-56},{68,-44}})));
    Modelica.Blocks.Continuous.Integrator integrator2(k=1, y_start=7.4)
      annotation (Placement(transformation(extent={{-14,18},{0,32}})));
    Modelica.Blocks.Math.Division division2
      annotation (Placement(transformation(extent={{-34,20},{-24,30}})));
    Modelica.Blocks.Math.Add add3(k2=-1)
      annotation (Placement(transformation(extent={{-58,28},{-44,42}})));
    F63 f63   annotation (Placement(transformation(extent={{44,18},{72,46}})));
    F63 f63const
              annotation (Placement(transformation(extent={{46,64},{74,92}})));
    Library.Constant PHUconst(Const=6.62536)
      annotation (Placement(transformation(extent={{-32,52},{-12,72}})));
  equation
    connect(integrator.y, add.u2) annotation (Line(
        points={{-11.3,-71},{2,-71},{2,-82},{-72,-82},{-72,-75.2},{-67.4,-75.2}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

    connect(add.y, division.u1) annotation (Line(
        points={{-51.3,-71},{-48.65,-71},{-48.65,-68},{-45,-68}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(division.y, integrator.u) annotation (Line(
        points={{-33.5,-71},{-27.4,-71}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(division.u2, TPHU1) annotation (Line(
        points={{-45,-74},{-48,-74},{-48,-88},{-92,-88}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product.u2, integrator.y) annotation (Line(
        points={{10.8,-69.6},{4.4,-69.6},{4.4,-71},{-11.3,-71}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(const.y, product.u1) annotation (Line(
        points={{2.4,-56},{8,-56},{8,-62.4},{10.8,-62.4}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product.y, add1.u2) annotation (Line(
        points={{24.6,-66},{30,-66},{30,-58.2},{31.6,-58.2}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(add1.y, product1.u2) annotation (Line(
        points={{47.7,-54},{51.75,-54},{51.75,-53.6},{54.8,-53.6}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(YNH40, product1.u1) annotation (Line(
        points={{-94,-28},{51.5,-28},{51.5,-46.4},{54.8,-46.4}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(add1.u1, const1.y) annotation (Line(
        points={{31.6,-49.8},{27.8,-49.8},{27.8,-49},{21.4,-49}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(YNH4, YNH4) annotation (Line(
        points={{82,-50},{82,-50}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product1.y, YNH4) annotation (Line(
        points={{68.6,-50},{82,-50}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(add.u1, PHU) annotation (Line(
        points={{-67.4,-66.8},{-73.7,-66.8},{-73.7,-53},{-93,-53}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(TPHA1, division2.u2) annotation (Line(
        points={{-91,22},{-35,22}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(division2.y, integrator2.u) annotation (Line(
        points={{-23.5,25},{-15.4,25}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(integrator2.y, add3.u2) annotation (Line(
        points={{0.7,25},{12,25},{12,6},{-66,6},{-66,30.8},{-59.4,30.8}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(add3.u1, PHA) annotation (Line(
        points={{-59.4,39.2},{-68.7,39.2},{-68.7,48},{-92,48}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(add3.y, division2.u1) annotation (Line(
        points={{-43.3,35},{-39.65,35},{-39.65,28},{-35,28}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(YTA1, YTA1) annotation (Line(
        points={{100,38},{100,38}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
  connect(integrator2.y, f63.PHA1)     annotation (Line(
        points={{0.7,25},{12,25},{12,34.8},{41.76,34.8}},
        color={0,0,127},
        smooth=Smooth.None,
        thickness=0.5));
  connect(YTA0, f63.YTA0)     annotation (Line(
        points={{-90,76},{20,76},{20,43.2},{41.76,43.2}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
  connect(f63.YTA1, YTA1)     annotation (Line(
        points={{74.24,34.31},{84.12,34.31},{84.12,38},{100,38}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

  connect(f63const.PHA1, integrator2.y) annotation (Line(
      points={{43.76,80.8},{28,80.8},{28,38},{8,38},{8,25},{0.7,25}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(YTA0, f63const.YTA0) annotation (Line(
      points={{-90,76},{-24,76},{-24,89.2},{43.76,89.2}},
      color={0,0,127},
      smooth=Smooth.None));
    connect(PHU, f63.PHU) annotation (Line(
        points={{-93,-53},{-74,-53},{-74,-6},{36,-6},{36,27.24},{41.76,27.24}},
        color={0,0,127},
        smooth=Smooth.None));

    connect(PHUconst.y, f63const.PHU) annotation (Line(
        points={{-5.9,62.1},{38,62.1},{38,73.24},{43.76,73.24}},
        color={0,0,127},
        smooth=Smooth.None));
    annotation (Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,
              -100},{100,100}}), graphics={
          Rectangle(
            extent={{-80,80},{80,-80}},
            lineColor={0,0,255},
            lineThickness=0.5),
          Text(
            extent={{-74,60},{-38,70}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="TPHU1"),
          Text(
            extent={{-74,14},{-36,24}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YNH40"),
          Text(
            extent={{-72,-14},{-42,-4}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YTA0"),
          Text(
            extent={{-72,36},{-38,46}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="TPHA1"),
          Text(
            extent={{-70,-40},{-42,-30}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="PHA"),
          Text(
            extent={{-72,-70},{-42,-60}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="PHU"),
          Text(
            extent={{36,42},{68,52}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YTA1"),
          Text(
            extent={{38,6},{78,16}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YNH4"),
          Text(
            extent={{-68,4},{68,24}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="Distal"),
          Text(
            extent={{-92,-26},{92,-4}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="renal"),
          Text(
            extent={{-86,-58},{98,-36}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="acidification")}),
      Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{
              100,100}}), graphics={
          Text(
            extent={{-18,-66},{8,-70}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="PHU1"),
          Text(
            extent={{-6,30},{20,26}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="PHA1"),
          Text(
            extent={{38,-66},{84,-70}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YNH4=YNH0*(-0.5*PHU1+4)"),
          Text(
            extent={{-66,-52},{-20,-60}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="der(PHU1)=(PHU-PHU1)/TPHU1"),
          Text(
            extent={{-42,44},{4,36}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="der(PHA1)=PHA-PHA1)/TPHA1")}),
      experiment(StopTime=6000),
      experimentSetupOutput);
  end RenalDistalAcidification;

  model TestRenalAcidification
    RenalAcidification renalAcidification
      annotation (Placement(transformation(extent={{30,-42},{92,20}})));
    Library.Constant PHA(Const=7.4)
      annotation (Placement(transformation(extent={{-90,-50},{-74,-34}})));
    Library.Constant ALD(Const=1)
      annotation (Placement(transformation(extent={{-86,-80},{-68,-62}})));
    Library.Constant YPO4(Const=0.025)
      annotation (Placement(transformation(extent={{-84,-24},{-64,-4}})));
    Library.Constant YORG(Const=0.01)
      annotation (Placement(transformation(extent={{-88,0},{-68,20}})));
    Library.Constant YTA0(Const=0.0068)
      annotation (Placement(transformation(extent={{-60,70},{-42,88}})));
    Library.Constant YNH0(Const=0.024)
      annotation (Placement(transformation(extent={{-56,48},{-40,64}})));
  equation
    connect(PHA.y, renalAcidification.PHA) annotation (Line(
        points={{-69.12,-41.92},{-22.78,-41.92},{-22.78,-18.44},{31.55,-18.44}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(ALD.y, renalAcidification.Ald) annotation (Line(
        points={{-62.51,-70.91},{14.22,-70.91},{14.22,-25.88},{31.55,-25.88}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(YNH0.y, renalAcidification.YNH40) annotation (Line(
        points={{-35.12,56.08},{-2.78,56.08},{-2.78,5.74},{31.55,5.74}},
        color={0,0,255},
        smooth=Smooth.None,
      thickness=0.5));
  connect(renalAcidification.YTA0, YTA0.y) annotation (Line(
      points={{30.93,13.8},{10.465,13.8},{10.465,79.09},{-36.51,79.09}},
      color={0,0,127},
      thickness=0.5,
      smooth=Smooth.None));
  connect(YORG.y, renalAcidification.YORG) annotation (Line(
      points={{-61.9,10.1},{-18.78,10.1},{-18.78,-2.32},{31.55,-2.32}},
      color={0,0,127},
      thickness=0.5,
      smooth=Smooth.None));
  connect(YPO4.y, renalAcidification.YPO4) annotation (Line(
      points={{-57.9,-13.9},{-24.95,-13.9},{-24.95,-10.38},{31.55,-10.38}},
      color={0,0,127},
      thickness=0.5,
      smooth=Smooth.None));
    annotation (Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
            -100},{100,100}}),        graphics),
      experiment(StopTime=6000),
      experimentSetupOutput);
  end TestRenalAcidification;

  model PHUCalculation

    function PHUcalc
      input Real ypo4;
      input Real yorg;
      input Real yta;
      input Real pha;
      output Real phu;
    protected
      Real a;
      Real b;
      Real c;
      Real XX1;
      Real c68;
      Real c43;
      Real cPHA;

    algorithm
      c68:=10^(-6.8);
      c43:=10^(-4.3);
      cPHA:=10^(-pha);
      a := -c43*c68*yorg-c43*cPHA*yorg-c43*c68*ypo4-c68*cPHA*ypo4+c43*c68*yta+c43*cPHA*yta+c68*cPHA*yta+cPHA^2*yta;
      b := -c43*c68^2*yorg + c43*cPHA^2*yorg - c43^2*c68*ypo4 +
      c68*cPHA^2*ypo4 + c43^2*c68*yta + c43*c68^2*yta + c43^2*cPHA*yta +
      2*c43*c68*cPHA*yta + c68^2*cPHA*yta + c43*cPHA^2*yta +
      c68*cPHA^2*yta;
      c := c43*c68^2*cPHA*yorg + c43*c68*cPHA^2*yorg + c43^2*c68*cPHA*ypo4 +
      c43*c68*cPHA^2*ypo4 + c43^2*c68^2*yta + c43^2*c68*cPHA*yta +
      c43*c68^2*cPHA*yta + c43*c68*cPHA^2*yta;

      XX1 := (-b - sqrt(b*b - 4*a*c))/(2*a);
      if (XX1>(10^(-3.5))) then
        XX1:=10^(-3.5);
      end if;
      if (XX1<0) then
         XX1:=10^(-3.5);
      end if;
      phu:=-Modelica.Math.log10(XX1);

    end PHUcalc;

    Modelica.Blocks.Interfaces.RealInput YPO4 annotation (Placement(
          transformation(
          extent={{-20,-20},{20,20}},
          rotation=0,
          origin={-90,80}), iconTransformation(
          extent={{-17,-17},{17,17}},
          rotation=270,
          origin={-27,69})));
    Modelica.Blocks.Interfaces.RealInput YORG annotation (Placement(
          transformation(extent={{-110,22},{-70,62}}),  iconTransformation(
          extent={{-17,-17},{17,17}},
          rotation=270,
          origin={41,71})));
    Modelica.Blocks.Interfaces.RealOutput PHU annotation (Placement(
          transformation(extent={{70,-61},{100,-31}}),iconTransformation(extent={
              {70,-10},{102,22}})));
    Modelica.Blocks.Interfaces.RealInput YTA annotation (Placement(transformation(
            extent={{-114,-66},{-74,-26}}),iconTransformation(extent={{-96,-14},{
              -56,26}})));
    Modelica.Blocks.Interfaces.RealInput PHA annotation (Placement(transformation(
            extent={{-110,-14},{-70,26}}),  iconTransformation(
          extent={{-20,-20},{20,20}},
          rotation=90,
          origin={14,-46})));

  equation
    PHU=PHUcalc(YPO4,YORG,YTA,PHA);

    annotation (
      uses(Modelica(version="3.1")),
      Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,
              100}}), graphics={
          Text(
            extent={{-4,42},{-48,52}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YPO4"),
          Text(
            extent={{64,42},{20,52}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YORG"),
          Text(
            extent={{-20,0},{-64,10}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YTA"),
          Text(
            extent={{78,-2},{34,8}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="PHU"),
          Text(
            extent={{36,-28},{-8,-18}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="PHA"),
          Rectangle(
            extent={{-76,68},{86,-54}},
            lineColor={0,0,255},
            lineThickness=0.5),
          Text(
            extent={{90,18},{-82,42}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="PHU Calculation")}),
      Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{
              100,100}}),
                      graphics));
  end PHUCalculation;

  block F63

    Library.Interfaces.RealInput PHU  annotation (Placement(transformation(extent={{-140,
              -58},{-100,-18}}),     iconTransformation(extent={{-132,-50},{-100,-18}})));
    Library.Interfaces.RealOutput YTA1 annotation (Placement(transformation(extent=
             {{80,-8},{120,32}}), iconTransformation(extent={{100,0},{132,33}})));
    function f63
      input Real pha1;
      input Real phu1;
      input Real yta0;
      output Real yta1;
    protected
      Real f62;
    algorithm
      f62:=yta0*(-2.5*pha1 + 19.5);
      if (phu1 <= 4.0) then
        yta1:=0;
      elseif (phu1<=5.0) then
        yta1:=f62*(phu1 - 4.0);
      else
        yta1:=f62;
      end if;
    end f63;

    Library.Interfaces.RealInput PHA1 annotation (Placement(transformation(extent={{-140,52},
              {-100,92}}),           iconTransformation(extent={{-132,4},{-100,36}})));
    Library.Interfaces.RealInput YTA0 annotation (Placement(transformation(extent={{-140,22},
              {-100,62}}),           iconTransformation(extent={{-132,64},{-100,96}})));
  equation
    YTA1 = f63(PHA1,PHU,YTA0);
    annotation (Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},
              {100,100}}),       graphics={Rectangle(
            extent={{-100,100},{100,-100}},
            lineColor={0,0,255},
            lineThickness=0.5), Text(
            extent={{-48,-46},{34,-96}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="F63")}), Diagram(coordinateSystem(preserveAspectRatio=true,
            extent={{-100,-100},{100,100}}), graphics));
  end F63;

  model RenalAcidification1

    Modelica.Blocks.Interfaces.RealInput YORG
      "renal excration rate of organic acid [mmol/min]"
                                              annotation (Placement(
          transformation(extent={{-2,-34},{20,-12}}),  iconTransformation(
            extent={{-104,19},{-86,37}})));
    Modelica.Blocks.Interfaces.RealInput YPO4
      "renal excration rate of phosphate [mmol/min]"
                                              annotation (Placement(
          transformation(extent={{-22,-42},{6,-14}}),  iconTransformation(
            extent={{-104,-7},{-86,11}})));
    Modelica.Blocks.Interfaces.RealInput PHA "pH of arterial blood"
                                             annotation (Placement(
          transformation(extent={{-120,-73},{-88,-42}}),iconTransformation(
            extent={{-104,-33},{-86,-15}})));
    Modelica.Blocks.Interfaces.RealInput Ald(unit="1") "effect of aldosterone"
                                             annotation (Placement(
          transformation(extent={{-102,-92},{-74,-64}}), iconTransformation(
            extent={{-104,-57},{-86,-39}})));
    Modelica.Blocks.Interfaces.RealOutput YTA
      "renal excration rate of titratable acid(default=0.0168) [mEq/min]"
                                              annotation (Placement(
          transformation(extent={{90,-6},{110,14}}), iconTransformation(extent={{90,31},
              {108,49}})));
    Modelica.Blocks.Interfaces.RealOutput YNH4
      "renal excration rate of ammonium(default=0.024) [mEq/min]"
                                               annotation (Placement(
          transformation(extent={{78,64},{98,84}}),  iconTransformation(extent={{92,3},{
              110,21}})));
    Modelica.Blocks.Interfaces.RealOutput PHU "pH of urine (defautl=6)"
                                              annotation (Placement(
          transformation(extent={{82,-40},{102,-20}}), iconTransformation(
            extent={{92,-33},{110,-15}})));
    Modelica.Blocks.Math.Product product
      annotation (Placement(transformation(extent={{-38,-90},{-24,-76}})));
    Modelica.Blocks.Math.Add add
      annotation (Placement(transformation(extent={{6,-98},{18,-86}})));
    Modelica.Blocks.Math.Add add1
      annotation (Placement(transformation(extent={{68,-4},{80,8}})));
    Modelica.Blocks.Interfaces.RealOutput YTA1 annotation (Placement(
          transformation(extent={{94,26},{114,46}}),  iconTransformation(extent={{92,67},
              {110,85}})));
    IKEDA.PHUCalculation pHUCaculation
      annotation (Placement(transformation(extent={{-2,-72},{42,-28}})));
    Modelica.Blocks.Interfaces.RealInput YNH40
      "Normal value of NH4 excretion [mEq/min]"
                                              annotation (Placement(
          transformation(extent={{4,42},{30,68}}),     iconTransformation(
            extent={{-104,45},{-86,63}})));
    Modelica.Blocks.Interfaces.RealInput YTA0
      "Normal value of titratable acids excretio [mEq/min]n"
                                              annotation (Placement(
          transformation(extent={{-20,24},{6,50}}),    iconTransformation(
            extent={{-106,71},{-88,89}})));
    Library.Constant TPHU1(Const=300)
      annotation (Placement(transformation(extent={{-86,38},{-72,52}})));
    Library.Constant K1(Const=0.001)
      annotation (Placement(transformation(extent={{-82,-102},{-68,-88}})));
    Library.Constant K2(Const=0.009)
      annotation (Placement(transformation(extent={{-30,-106},{-16,-92}})));
    Library.Constant TPHA1(Const=200)
      annotation (Placement(transformation(extent={{-58,0},{-44,14}})));
    Modelica.Blocks.Continuous.Integrator integrator2(k=1, y_start=7.4)
      annotation (Placement(transformation(extent={{-4,6},{10,20}})));
    Modelica.Blocks.Math.Add add3(k2=-1)
      annotation (Placement(transformation(extent={{-48,16},{-34,30}})));
    Modelica.Blocks.Math.Division division2
      annotation (Placement(transformation(extent={{-24,8},{-14,18}})));
    F63 f63   annotation (Placement(transformation(extent={{30,12},{58,40}})));
    Modelica.Blocks.Continuous.Integrator integrator(y_start=6.0, k=1)
      annotation (Placement(transformation(extent={{-40,60},{-26,74}})));
    Modelica.Blocks.Math.Add add2(
                                 k2=-1)
      annotation (Placement(transformation(extent={{-80,54},{-66,68}})));
    Modelica.Blocks.Math.Product product1
      annotation (Placement(transformation(extent={{-2,66},{10,78}})));
    Modelica.Blocks.Math.Division division
      annotation (Placement(transformation(extent={{-58,56},{-48,66}})));
    Modelica.Blocks.Sources.Constant const(k=-0.5)
      annotation (Placement(transformation(extent={{-26,82},{-16,92}})));
    Modelica.Blocks.Math.Add add4(k2=+1)
      annotation (Placement(transformation(extent={{19,71},{33,85}})));
    Modelica.Blocks.Sources.Constant const1(k=4)
      annotation (Placement(transformation(extent={{-5,85},{3,93}})));
    Modelica.Blocks.Math.Product product2
      annotation (Placement(transformation(extent={{50,68},{62,80}})));
  equation
    connect(Ald, product.u1) annotation (Line(
        points={{-88,-78},{-44,-78},{-44,-78.8},{-39.4,-78.8}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product.y, add.u1) annotation (Line(
        points={{-23.3,-83},{-9.65,-83},{-9.65,-88.4},{4.8,-88.4}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(YTA, YTA) annotation (Line(
        points={{100,4},{100,4}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(add1.y, YTA) annotation (Line(
        points={{80.6,2},{86,2},{86,4},{100,4}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(add.y, add1.u2) annotation (Line(
        points={{18.6,-92},{60,-92},{60,-1.6},{66.8,-1.6}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pHUCaculation.YTA, add1.y) annotation (Line(
        points={{3.28,-48.68},{-38,-48.68},{-38,-12},{86,-12},{86,2},{80.6,2}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

    connect(YPO4, pHUCaculation.YPO4) annotation (Line(
        points={{-8,-28},{14.06,-28},{14.06,-34.82}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(YORG, pHUCaculation.YORG) annotation (Line(
        points={{9,-23},{29.02,-23},{29.02,-34.38}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pHUCaculation.PHA, PHA) annotation (Line(
        points={{23.08,-60.12},{23.08,-68},{-68,-68},{-68,-57.5},{-104,-57.5}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pHUCaculation.PHU, PHU) annotation (Line(
        points={{38.92,-48.68},{60.13,-48.68},{60.13,-30},{92,-30}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

    connect(PHU, PHU) annotation (Line(
        points={{92,-30},{92,-30}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(K2.y, add.u2) annotation (Line(
        points={{-11.73,-98.93},{0,-98.93},{0,-95.6},{4.8,-95.6}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(K1.y, product.u2) annotation (Line(
        points={{-63.73,-94.93},{-48,-94.93},{-48,-87.2},{-39.4,-87.2}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

    connect(integrator2.y,add3. u2) annotation (Line(
        points={{10.7,13},{14,13},{14,-6},{-64,-6},{-64,18.8},{-49.4,18.8}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(add3.y,division2. u1) annotation (Line(
        points={{-33.3,23},{-29.65,23},{-29.65,16},{-25,16}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(division2.y,integrator2. u) annotation (Line(
        points={{-13.5,13},{-10,14},{-10,13},{-5.4,13}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(PHA, add3.u1) annotation (Line(
        points={{-104,-57.5},{-80,-57.5},{-80,27.2},{-49.4,27.2}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(f63.PHA1, integrator2.y) annotation (Line(
        points={{27.76,28.8},{20,28.8},{20,13},{10.7,13}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(TPHA1.y, division2.u2) annotation (Line(
        points={{-39.73,7.07},{-31.865,7.07},{-31.865,10},{-25,10}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(add1.u1, f63.YTA1) annotation (Line(
        points={{66.8,5.6},{62,5.6},{62,28.31},{60.24,28.31}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(f63.YTA1, YTA1) annotation (Line(
        points={{60.24,28.31},{62,28.31},{62,36},{104,36}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(YTA0, f63.YTA0) annotation (Line(
        points={{-7,37},{9.5,37},{9.5,37.2},{27.76,37.2}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(integrator.y, add2.u2)
                                  annotation (Line(
        points={{-25.3,67},{-16,67},{-16,36},{-90,36},{-90,56.8},{-81.4,56.8}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(add2.y, division.u1)
                                annotation (Line(
        points={{-65.3,61},{-62.65,61},{-62.65,64},{-59,64}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(division.y,integrator. u) annotation (Line(
        points={{-47.5,61},{-44,60},{-44,67},{-41.4,67}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(add4.u1,const1. y) annotation (Line(
        points={{17.6,82.2},{13.8,82.2},{13.8,89},{3.4,89}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(add2.u1, pHUCaculation.PHU) annotation (Line(
        points={{-81.4,65.2},{-92,65.2},{-92,-8},{54,-8},{54,-48.68},{38.92,
            -48.68}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(TPHU1.y, division.u2) annotation (Line(
        points={{-67.73,45.07},{-62,45.07},{-62,58},{-59,58}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(integrator.y, product1.u2) annotation (Line(
        points={{-25.3,67},{-13.65,67},{-13.65,68.4},{-3.2,68.4}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(const.y, product1.u1) annotation (Line(
        points={{-15.5,87},{-10,87},{-10,75.6},{-3.2,75.6}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product1.y, add4.u2) annotation (Line(
        points={{10.6,72},{16,72},{16,73.8},{17.6,73.8}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(add4.y, product2.u1) annotation (Line(
        points={{33.7,78},{41.25,78},{41.25,77.6},{48.8,77.6}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product2.u2, YNH40) annotation (Line(
        points={{48.8,70.4},{40,70.4},{40,55},{17,55}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product2.y, YNH4) annotation (Line(
        points={{62.6,74},{88,74}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pHUCaculation.PHU, f63.PHU) annotation (Line(
        points={{38.92,-48.68},{54,-48.68},{54,0},{24,0},{24,21.24},{27.76,
            21.24}},
        color={0,0,127},
        smooth=Smooth.None));
    annotation (Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
              -100},{100,100}}), graphics={Text(
            extent={{6,-80},{74,-76}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YTA=0.001*Ald+0.009+YTA1"),
          Text(
            extent={{-32,66},{-6,62}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="PHU1")}),                     Icon(coordinateSystem(
            preserveAspectRatio=true, extent={{-100,-100},{100,100}}), graphics={
          Rectangle(
            extent={{-100,100},{100,-100}},
            lineColor={0,0,255},
            lineThickness=0.5),
          Text(
            extent={{98,-96},{-96,-60}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="acidification"),
          Text(
            extent={{-92,20},{-32,36}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YORG"),
          Text(
            extent={{-94,-6},{-36,10}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YPO4"),
          Text(
            extent={{-90,-30},{-40,-14}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="PHA"),
          Text(
            extent={{-94,-58},{-38,-40}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="Ald"),
          Text(
            extent={{34,34},{100,48}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YTA"),
          Text(
            extent={{22,4},{100,20}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YNH4"),
          Text(
            extent={{34,-30},{100,-16}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="PHU"),
          Text(
            extent={{30,68},{100,84}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YTA1"),
          Text(
            extent={{60,-64},{-50,-28}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="Renal"),
          Text(
            extent={{-92,46},{-32,62}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YNH40"),
          Text(
            extent={{-94,72},{-34,88}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="YTA0")}));
  end RenalAcidification1;

  model TestRenalAcidification1
    Library.Constant YTA0(Const=0.0068)
      annotation (Placement(transformation(extent={{-86,76},{-68,94}})));
    Library.Constant YNH0(Const=0.024)
      annotation (Placement(transformation(extent={{-92,50},{-76,66}})));
    Library.Constant YORG(Const=0.01)
      annotation (Placement(transformation(extent={{-78,10},{-58,30}})));
    Library.Constant YPO4(Const=0.025)
      annotation (Placement(transformation(extent={{-74,-14},{-54,6}})));
    Library.Constant PHA(Const=7.4)
      annotation (Placement(transformation(extent={{-80,-40},{-64,-24}})));
    Library.Constant ALD(Const=1)
      annotation (Placement(transformation(extent={{-76,-70},{-58,-52}})));
    RenalAcidification1 renalAcidification1_1
      annotation (Placement(transformation(extent={{-12,-36},{98,74}})));
  equation
    connect(YTA0.y, renalAcidification1_1.YTA0) annotation (Line(
        points={{-62.51,85.09},{-36,85.09},{-36,63},{-10.35,63}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(YNH0.y, renalAcidification1_1.YNH40) annotation (Line(
        points={{-71.12,58.08},{-48,58.08},{-48,48.7},{-9.25,48.7}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(YORG.y, renalAcidification1_1.YORG) annotation (Line(
        points={{-51.9,20.1},{-34,20.1},{-34,34.4},{-9.25,34.4}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(YPO4.y, renalAcidification1_1.YPO4) annotation (Line(
        points={{-47.9,-3.9},{-32,-3.9},{-32,20.1},{-9.25,20.1}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(renalAcidification1_1.PHA, PHA.y) annotation (Line(
        points={{-9.25,5.8},{-28,5.8},{-28,-31.92},{-59.12,-31.92}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(ALD.y, renalAcidification1_1.Ald) annotation (Line(
        points={{-52.51,-60.91},{-22,-60.91},{-22,-7.4},{-9.25,-7.4}},
        color={0,0,127},
        smooth=Smooth.None));
    annotation (Diagram(graphics));
  end TestRenalAcidification1;
  annotation (uses(Modelica(version="3.2")));
end IKEDA;


model IKEDA_TestRenalAcidification
 extends IKEDA.TestRenalAcidification;
  annotation(experiment(StopTime=6000),
    Diagram(graphics),
    uses(Modelica(version="3.2")));
end IKEDA_TestRenalAcidification;
