within ;
package Modelica "Modelica Standard Library (Version 3.2)"
extends Modelica.Icons.Package;

  package Blocks
    "Library of basic input/output control blocks (continuous, discrete, logical, table blocks)"
  import SI = Modelica.SIunits;
  extends Modelica.Icons.Package;

    package Interfaces
      "Library of connectors and partial models for input/output blocks"
      import Modelica.SIunits;
        extends Modelica.Icons.InterfacesPackage;

    connector RealInput = input Real "'input Real' as connector"
      annotation (defaultComponentName="u",
      Icon(graphics={Polygon(
              points={{-100,100},{100,0},{-100,-100},{-100,100}},
              lineColor={0,0,127},
              fillColor={0,0,127},
              fillPattern=FillPattern.Solid)},
           coordinateSystem(extent={{-100,-100},{100,100}}, preserveAspectRatio=true, initialScale=0.2)),
      Diagram(coordinateSystem(
            preserveAspectRatio=true, initialScale=0.2,
            extent={{-100,-100},{100,100}},
            grid={1,1}), graphics={Polygon(
              points={{0,50},{100,0},{0,-50},{0,50}},
              lineColor={0,0,127},
              fillColor={0,0,127},
              fillPattern=FillPattern.Solid), Text(
              extent={{-10,85},{-10,60}},
              lineColor={0,0,127},
              textString="%name")}),
        Documentation(info="<html>
<p>
Connector with one input signal of type Real.
</p>
</html>"));

    connector RealOutput = output Real "'output Real' as connector"
      annotation (defaultComponentName="y",
      Icon(coordinateSystem(
            preserveAspectRatio=true,
            extent={{-100,-100},{100,100}},
            grid={1,1}), graphics={Polygon(
              points={{-100,100},{100,0},{-100,-100},{-100,100}},
              lineColor={0,0,127},
              fillColor={255,255,255},
              fillPattern=FillPattern.Solid)}),
      Diagram(coordinateSystem(
            preserveAspectRatio=true,
            extent={{-100,-100},{100,100}},
            grid={1,1}), graphics={Polygon(
              points={{-100,50},{0,0},{-100,-50},{-100,50}},
              lineColor={0,0,127},
              fillColor={255,255,255},
              fillPattern=FillPattern.Solid), Text(
              extent={{30,110},{30,60}},
              lineColor={0,0,127},
              textString="%name")}),
        Documentation(info="<html>
<p>
Connector with one output signal of type Real.
</p>
</html>"));

        partial block BlockIcon "Basic graphical layout of input/output block"

          annotation (
            Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{
                  100,100}}), graphics={Rectangle(
                extent={{-100,-100},{100,100}},
                lineColor={0,0,127},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid), Text(
                extent={{-150,150},{150,110}},
                textString="%name",
                lineColor={0,0,255})}),
          Documentation(info="<html>
<p>
Block that has only the basic icon for an input/output
block (no declarations, no equations). Most blocks
of package Modelica.Blocks inherit directly or indirectly
from this block.
</p>
</html>"));

        end BlockIcon;

        partial block SI2SO
        "2 Single Input / 1 Single Output continuous control block"
          extends BlockIcon;

          RealInput u1 "Connector of Real input signal 1"
            annotation (Placement(transformation(extent={{-140,40},{-100,80}},
                rotation=0)));
          RealInput u2 "Connector of Real input signal 2"
            annotation (Placement(transformation(extent={{-140,-80},{-100,-40}},
                rotation=0)));
          RealOutput y "Connector of Real output signal"
            annotation (Placement(transformation(extent={{100,-10},{120,10}},
                rotation=0)));

          annotation (
            Documentation(info="<html>
<p>
Block has two continuous Real input signals u1 and u2 and one
continuous Real output signal y.
</p>
</html>"),  Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics));

        end SI2SO;
        annotation (
          Documentation(info="<HTML>
<p>
This package contains interface definitions for
<b>continuous</b> input/output blocks with Real,
Integer and Boolean signals. Furthermore, it contains
partial models for continuous and discrete blocks.
</p>

</HTML>
",     revisions="<html>
<ul>
<li><i>Oct. 21, 2002</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>
       and <a href=\"http://www.robotic.dlr.de/Christian.Schweiger/\">Christian Schweiger</a>:<br>
       Added several new interfaces. <a href=\"modelica://Modelica/Documentation/ChangeNotes1.5.html\">Detailed description</a> available.
<li><i>Oct. 24, 1999</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       RealInputSignal renamed to RealInput. RealOutputSignal renamed to
       output RealOutput. GraphBlock renamed to BlockIcon. SISOreal renamed to
       SISO. SOreal renamed to SO. I2SOreal renamed to M2SO.
       SignalGenerator renamed to SignalSource. Introduced the following
       new models: MIMO, MIMOs, SVcontrol, MVcontrol, DiscreteBlockIcon,
       DiscreteBlock, DiscreteSISO, DiscreteMIMO, DiscreteMIMOs,
       BooleanBlockIcon, BooleanSISO, BooleanSignalSource, MI2BooleanMOs.</li>
<li><i>June 30, 1999</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       Realized a first version, based on an existing Dymola library
       of Dieter Moormann and Hilding Elmqvist.</li>
</ul>
</html>
"));
    end Interfaces;

    package Math
      "Library of Real mathematical functions as input/output blocks"
      import Modelica.SIunits;
      import Modelica.Blocks.Interfaces;
      extends Modelica.Icons.Package;

          block Add
        "Output the sum of the two inputs (this is an obsolet block. Use instead MultiSum)"
            extends Interfaces.SI2SO;
            parameter Real k1=+1 "Gain of upper input";
            parameter Real k2=+1 "Gain of lower input";

          equation
            y = k1*u1 + k2*u2;
            annotation (
              Documentation(info="
<HTML>
<p>
This blocks computes output <b>y</b> as <i>sum</i> of the
two input signals <b>u1</b> and <b>u2</b>:
</p>
<pre>
    <b>y</b> = k1*<b>u1</b> + k2*<b>u2</b>;
</pre>
<p>
Example:
</p>
<pre>
     parameter:   k1= +2, k2= -3

  results in the following equations:

     y = 2 * u1 - 3 * u2
</pre>

</HTML>
"),           Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics={
              Text(
                extent={{-98,-52},{7,-92}},
                lineColor={0,0,0},
                textString="%k2"),
              Text(
                extent={{-100,90},{5,50}},
                lineColor={0,0,0},
                textString="%k1"),
              Text(
                extent={{-150,150},{150,110}},
                textString="%name",
                lineColor={0,0,255}),
              Line(points={{-100,60},{-40,60},{-30,40}}, color={0,0,255}),
              Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,255}),
              Line(points={{-100,-60},{-40,-60},{-30,-40}}, color={0,0,255}),
              Line(points={{-15,-25.99},{15,25.99}}, color={0,0,0}),
              Rectangle(
                extent={{-100,-100},{100,100}},
                lineColor={0,0,127},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Line(points={{50,0},{100,0}}, color={0,0,255}),
              Line(points={{-100,60},{-74,24},{-44,24}}, color={0,0,127}),
              Line(points={{-100,-60},{-74,-28},{-42,-28}}, color={0,0,127}),
              Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,127}),
              Line(points={{50,0},{100,0}}, color={0,0,127}),
              Text(
                extent={{-38,34},{38,-34}},
                lineColor={0,0,0},
                textString="+"),
              Text(
                extent={{-100,52},{5,92}},
                lineColor={0,0,0},
                textString="%k1"),
              Text(
                extent={{-100,-52},{5,-92}},
                lineColor={0,0,0},
                textString="%k2")}),
              Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics={
              Rectangle(
                extent={{-100,-100},{100,100}},
                lineColor={0,0,255},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-98,-52},{7,-92}},
                lineColor={0,0,0},
                textString="%k2"),
              Text(
                extent={{-100,90},{5,50}},
                lineColor={0,0,0},
                textString="%k1"),
              Line(points={{-100,60},{-40,60},{-30,40}}, color={0,0,255}),
              Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,255}),
              Line(points={{-100,-60},{-40,-60},{-30,-40}}, color={0,0,255}),
              Line(points={{-15,-25.99},{15,25.99}}, color={0,0,0}),
              Rectangle(
                extent={{-100,-100},{100,100}},
                lineColor={0,0,127},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Line(points={{50,0},{100,0}}, color={0,0,255}),
              Line(points={{-100,60},{-74,24},{-44,24}}, color={0,0,127}),
              Line(points={{-100,-60},{-74,-28},{-42,-28}}, color={0,0,127}),
              Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,127}),
              Line(points={{50,0},{100,0}}, color={0,0,127}),
              Text(
                extent={{-38,34},{38,-34}},
                lineColor={0,0,0},
                textString="+"),
              Text(
                extent={{-100,52},{5,92}},
                lineColor={0,0,0},
                textString="k1"),
              Text(
                extent={{-100,-52},{5,-92}},
                lineColor={0,0,0},
                textString="k2")}));
          end Add;

          block Product
        "Output product of the two inputs (this is an obsolet block. Use instead MultiProduct)"
            extends Interfaces.SI2SO;

          equation
            y = u1*u2;
            annotation (
              Documentation(info="
<HTML>
<p>
This blocks computes the output <b>y</b> (element-wise)
as <i>product</i> of the corresponding elements of
the two inputs <b>u1</b> and <b>u2</b>:
</p>
<pre>
    y = u1 * u2;
</pre>

</HTML>
"),           Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics={
              Line(points={{-100,60},{-40,60},{-30,40}}, color={0,0,127}),
              Line(points={{-100,-60},{-40,-60},{-30,-40}}, color={0,0,127}),
              Line(points={{50,0},{100,0}}, color={0,0,127}),
              Line(points={{-30,0},{30,0}}, color={0,0,0}),
              Line(points={{-15,25.99},{15,-25.99}}, color={0,0,0}),
              Line(points={{-15,-25.99},{15,25.99}}, color={0,0,0}),
              Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,127})}),
              Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics={
              Rectangle(
                extent={{-100,-100},{100,100}},
                lineColor={0,0,255},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Line(points={{-100,60},{-40,60},{-30,40}}, color={0,0,255}),
              Line(points={{-100,-60},{-40,-60},{-30,-40}}, color={0,0,255}),
              Line(points={{50,0},{100,0}}, color={0,0,255}),
              Line(points={{-30,0},{30,0}}, color={0,0,0}),
              Line(points={{-15,25.99},{15,-25.99}}, color={0,0,0}),
              Line(points={{-15,-25.99},{15,25.99}}, color={0,0,0}),
              Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,255})}));
          end Product;

          block Division "Output first input divided by second input"
            extends Interfaces.SI2SO;

          equation
            y = u1/u2;
            annotation (
              Documentation(info="
<HTML>
<p>
This block computes the output <b>y</b> (element-wise)
by <i>dividing</i> the corresponding elements of
the two inputs <b>u1</b> and <b>u2</b>:
</p>
<pre>
    y = u1 / u2;
</pre>

</HTML>
"),           Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics={
              Line(points={{50,0},{100,0}}, color={0,0,127}),
              Line(points={{-30,0},{30,0}}, color={0,0,0}),
              Ellipse(
                extent={{-5,20},{5,30}},
                lineColor={0,0,0},
                fillColor={0,0,0},
                fillPattern=FillPattern.Solid),
              Ellipse(
                extent={{-5,-20},{5,-30}},
                lineColor={0,0,0},
                fillColor={0,0,0},
                fillPattern=FillPattern.Solid),
              Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,127}),
              Text(
                extent={{-150,150},{150,110}},
                textString="%name",
                lineColor={0,0,255}),
              Line(points={{-100,60},{-66,60},{-40,30}}, color={0,0,127}),
              Line(points={{-100,-60},{0,-60},{0,-50}}, color={0,0,127})}),
              Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics={
              Rectangle(
                extent={{-100,-100},{100,100}},
                lineColor={0,0,255},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Line(points={{50,0},{100,0}}, color={0,0,255}),
              Line(points={{-30,0},{30,0}}, color={0,0,0}),
              Ellipse(
                extent={{-5,20},{5,30}},
                lineColor={0,0,0},
                fillColor={0,0,0},
                fillPattern=FillPattern.Solid),
              Ellipse(
                extent={{-5,-20},{5,-30}},
                lineColor={0,0,0},
                fillColor={0,0,0},
                fillPattern=FillPattern.Solid),
              Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,255}),
              Line(points={{-100,60},{-66,60},{-40,30}}, color={0,0,255}),
              Line(points={{-100,-60},{0,-60},{0,-50}}, color={0,0,255})}));
          end Division;
      annotation (
        Documentation(info="
<HTML>
<p>
This package contains basic <b>mathematical operations</b>,
such as summation and multiplication, and basic <b>mathematical
functions</b>, such as <b>sqrt</b> and <b>sin</b>, as
input/output blocks. All blocks of this library can be either
connected with continuous blocks or with sampled-data blocks.
</p>
</HTML>
",     revisions="<html>
<ul>
<li><i>October 21, 2002</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>
       and <a href=\"http://www.robotic.dlr.de/Christian.Schweiger/\">Christian Schweiger</a>:<br>
       New blocks added: RealToInteger, IntegerToReal, Max, Min, Edge, BooleanChange, IntegerChange.</li>
<li><i>August 7, 1999</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       Realized (partly based on an existing Dymola library
       of Dieter Moormann and Hilding Elmqvist).
</li>
</ul>
</html>"));
    end Math;
  annotation (
    Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,100}}),
        graphics={
        Rectangle(extent={{-32,-6},{16,-35}}, lineColor={0,0,0}),
        Rectangle(extent={{-32,-56},{16,-85}}, lineColor={0,0,0}),
        Line(points={{16,-20},{49,-20},{49,-71},{16,-71}}, color={0,0,0}),
        Line(points={{-32,-72},{-64,-72},{-64,-21},{-32,-21}}, color={0,0,0}),
        Polygon(
          points={{16,-71},{29,-67},{29,-74},{16,-71}},
          lineColor={0,0,0},
          fillColor={0,0,0},
          fillPattern=FillPattern.Solid),
        Polygon(
          points={{-32,-21},{-46,-17},{-46,-25},{-32,-21}},
          lineColor={0,0,0},
          fillColor={0,0,0},
          fillPattern=FillPattern.Solid)}),
                            Documentation(info="<html>
<p>
This library contains input/output blocks to build up block diagrams.
</p>

<dl>
<dt><b>Main Author:</b>
<dd><a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a><br>
    Deutsches Zentrum f&uuml;r Luft und Raumfahrt e. V. (DLR)<br>
    Oberpfaffenhofen<br>
    Postfach 1116<br>
    D-82230 Wessling<br>
    email: <A HREF=\"mailto:Martin.Otter@dlr.de\">Martin.Otter@dlr.de</A><br>
</dl>
<p>
Copyright &copy; 1998-2010, Modelica Association and DLR.
</p>
<p>
<i>This Modelica package is <u>free</u> software and the use is completely at <u>your own risk</u>; it can be redistributed and/or modified under the terms of the Modelica License 2. For license conditions (including the disclaimer of warranty) see <a href=\"modelica://Modelica.UsersGuide.ModelicaLicense2\">Modelica.UsersGuide.ModelicaLicense2</a> or visit <a href=\"http://www.modelica.org/licenses/ModelicaLicense2\"> http://www.modelica.org/licenses/ModelicaLicense2</a>.</i>
</p>
</HTML>
",   revisions="<html>
<ul>
<li><i>June 23, 2004</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       Introduced new block connectors and adapated all blocks to the new connectors.
       Included subpackages Continuous, Discrete, Logical, Nonlinear from
       package ModelicaAdditions.Blocks.
       Included subpackage ModelicaAdditions.Table in Modelica.Blocks.Sources
       and in the new package Modelica.Blocks.Tables.
       Added new blocks to Blocks.Sources and Blocks.Logical.
       </li>
<li><i>October 21, 2002</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>
       and <a href=\"http://www.robotic.dlr.de/Christian.Schweiger/\">Christian Schweiger</a>:<br>
       New subpackage Examples, additional components.
       </li>
<li><i>June 20, 2000</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a> and
       Michael Tiller:<br>
       Introduced a replaceable signal type into
       Blocks.Interfaces.RealInput/RealOutput:
<pre>
   replaceable type SignalType = Real
</pre>
       in order that the type of the signal of an input/output block
       can be changed to a physical type, for example:
<pre>
   Sine sin1(outPort(redeclare type SignalType=Modelica.SIunits.Torque))
</pre>
      </li>
<li><i>Sept. 18, 1999</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       Renamed to Blocks. New subpackages Math, Nonlinear.
       Additional components in subpackages Interfaces, Continuous
       and Sources. </li>
<li><i>June 30, 1999</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       Realized a first version, based on an existing Dymola library
       of Dieter Moormann and Hilding Elmqvist.</li>
</ul>
</html>"));
  end Blocks;

  package Math
    "Library of mathematical functions (e.g., sin, cos) and of functions operating on vectors and matrices"
  import SI = Modelica.SIunits;
  extends Modelica.Icons.Package;

  function log10 "Base 10 logarithm (u shall be > 0)"
    extends baseIcon1;
    input Real u;
    output Real y;

  external "builtin" y=  log10(u);
    annotation (
      Icon(coordinateSystem(
          preserveAspectRatio=true,
          extent={{-100,-100},{100,100}},
          grid={2,2}), graphics={
          Line(points={{-90,0},{68,0}}, color={192,192,192}),
          Polygon(
            points={{90,0},{68,8},{68,-8},{90,0}},
            lineColor={192,192,192},
            fillColor={192,192,192},
            fillPattern=FillPattern.Solid),
          Line(points={{-79.8,-80},{-79.2,-50.6},{-78.4,-37},{-77.6,-28},{-76.8,-21.3},
                {-75.2,-11.4},{-72.8,-1.31},{-69.5,8.08},{-64.7,17.9},{-57.5,28},
                {-47,38.1},{-31.8,48.1},{-10.1,58},{22.1,68},{68.7,78.1},{80,80}},
              color={0,0,0}),
          Text(
            extent={{-30,-22},{60,-70}},
            lineColor={192,192,192},
            textString="log10")}),
      Diagram(coordinateSystem(
          preserveAspectRatio=true,
          extent={{-100,-100},{100,100}},
          grid={2,2}), graphics={
          Line(points={{-100,0},{84,0}}, color={95,95,95}),
          Polygon(
            points={{98,0},{82,6},{82,-6},{98,0}},
            lineColor={95,95,95},
            fillColor={95,95,95},
            fillPattern=FillPattern.Solid),
          Line(
            points={{-77.8,-80},{-77.2,-50.6},{-76.4,-37},{-75.6,-28},{-74.8,-21.3},
                {-73.2,-11.4},{-70.8,-1.31},{-67.5,8.08},{-62.7,17.9},{-55.5,28},
                {-45,38.1},{-29.8,48.1},{-8.1,58},{24.1,68},{70.7,78.1},{82,80}},
            color={0,0,255},
            thickness=0.5),
          Text(
            extent={{66,-13},{86,-33}},
            textString="20",
            lineColor={0,0,255}),
          Text(
            extent={{-78,-1},{-58,-21}},
            textString="1",
            lineColor={0,0,255}),
          Text(
            extent={{-83,62},{-63,78}},
            textString=" 1.3",
            lineColor={0,0,255}),
          Text(
            extent={{80,24},{100,4}},
            lineColor={95,95,95},
            textString="u"),
          Text(
            extent={{-100,9},{-80,-11}},
            textString="0",
            lineColor={0,0,255}),
          Line(
            points={{-80,80},{86,80}},
            color={175,175,175},
            smooth=Smooth.None),
          Line(
            points={{80,92},{80,-12}},
            color={175,175,175},
            smooth=Smooth.None)}),
      Documentation(info="<html>
<p>
This function returns y = log10(u),
with u &gt; 0:
</p>

<p>
<img src=\"modelica://Modelica/Resources/Images/Math/log10.png\">
</p>
</html>"),   Library="ModelicaExternalC");
  end log10;

  partial function baseIcon1
      "Basic icon for mathematical function with y-axis on left side"

    annotation (Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,
              -100},{100,100}}), graphics={
          Rectangle(
            extent={{-100,100},{100,-100}},
            lineColor={0,0,0},
            fillColor={255,255,255},
            fillPattern=FillPattern.Solid),
          Line(points={{-80,-80},{-80,68}}, color={192,192,192}),
          Polygon(
            points={{-80,90},{-88,68},{-72,68},{-80,90}},
            lineColor={192,192,192},
            fillColor={192,192,192},
            fillPattern=FillPattern.Solid),
          Text(
            extent={{-150,150},{150,110}},
            textString="%name",
            lineColor={0,0,255})}),                          Diagram(
          coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,
              100}}), graphics={
          Line(points={{-80,80},{-88,80}}, color={95,95,95}),
          Line(points={{-80,-80},{-88,-80}}, color={95,95,95}),
          Line(points={{-80,-90},{-80,84}}, color={95,95,95}),
          Text(
            extent={{-75,104},{-55,84}},
            lineColor={95,95,95},
            textString="y"),
          Polygon(
            points={{-80,98},{-86,82},{-74,82},{-80,98}},
            lineColor={95,95,95},
            fillColor={95,95,95},
            fillPattern=FillPattern.Solid)}),
      Documentation(info="<html>
<p>
Icon for a mathematical function, consisting of an y-axis on the left side.
It is expected, that an x-axis is added and a plot of the function.
</p>
</html>"));
  end baseIcon1;
  annotation (
    Invisible=true,
    Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,100}}),
        graphics={Text(
          extent={{-59,-9},{42,-56}},
          lineColor={0,0,0},
          textString="f(x)")}),
    Documentation(info="<HTML>
<p>
This package contains <b>basic mathematical functions</b> (such as sin(..)),
as well as functions operating on
<a href=\"modelica://Modelica.Math.Vectors\">vectors</a>,
<a href=\"modelica://Modelica.Math.Matrices\">matrices</a>,
<a href=\"modelica://Modelica.Math.Nonlinear\">nonlinear functions</a>, and
<a href=\"modelica://Modelica.Math.BooleanVectors\">Boolean vectors</a>.
</p>

<dl>
<dt><b>Main Authors:</b>
<dd><a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a> and
    Marcus Baur<br>
    Deutsches Zentrum f&uuml;r Luft und Raumfahrt e.V. (DLR)<br>
    Institut f&uuml;r Robotik und Mechatronik<br>
    Postfach 1116<br>
    D-82230 Wessling<br>
    Germany<br>
    email: <A HREF=\"mailto:Martin.Otter@dlr.de\">Martin.Otter@dlr.de</A><br>
</dl>

<p>
Copyright &copy; 1998-2010, Modelica Association and DLR.
</p>
<p>
<i>This Modelica package is <u>free</u> software and the use is completely at <u>your own risk</u>; it can be redistributed and/or modified under the terms of the Modelica License 2. For license conditions (including the disclaimer of warranty) see <a href=\"modelica://Modelica.UsersGuide.ModelicaLicense2\">Modelica.UsersGuide.ModelicaLicense2</a> or visit <a href=\"http://www.modelica.org/licenses/ModelicaLicense2\"> http://www.modelica.org/licenses/ModelicaLicense2</a>.</i>
</p>
</HTML>
",   revisions="<html>
<ul>
<li><i>October 21, 2002</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>
       and <a href=\"http://www.robotic.dlr.de/Christian.Schweiger/\">Christian Schweiger</a>:<br>
       Function tempInterpol2 added.</li>
<li><i>Oct. 24, 1999</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       Icons for icon and diagram level introduced.</li>
<li><i>June 30, 1999</i>
       by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br>
       Realized.</li>
</ul>

</html>"));
  end Math;

  package Icons "Library of icons"
    extends Icons.Package;

    partial package Package "Icon for standard packages"

      annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                -100},{100,100}}), graphics={Rectangle(
              extent={{-80,100},{100,-80}},
              lineColor={0,0,0},
              fillColor={215,230,240},
              fillPattern=FillPattern.Solid), Rectangle(
              extent={{-100,80},{80,-100}},
              lineColor={0,0,0},
              fillColor={240,240,240},
              fillPattern=FillPattern.Solid)}),
                                Documentation(info="<html>
<p>Standard package icon.</p>
</html>"));
    end Package;

    partial package InterfacesPackage "Icon for packages containing interfaces"
    //extends Modelica.Icons.Package;
      annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                -100},{100,100}}), graphics={Rectangle(
              extent={{-80,100},{100,-80}},
              lineColor={0,0,0},
              fillColor={215,230,240},
              fillPattern=FillPattern.Solid), Rectangle(
              extent={{-100,80},{80,-100}},
              lineColor={0,0,0},
              fillColor={240,240,240},
              fillPattern=FillPattern.Solid),
            Polygon(
              points={{0,50},{20,50},{50,10},{80,10},{80,-30},{50,-30},{20,-70},{
                  0,-70},{0,50}},
              lineColor={0,0,0},
              smooth=Smooth.None,
              fillColor={215,215,215},
              fillPattern=FillPattern.Solid),
            Polygon(
              points={{-100,10},{-70,10},{-40,50},{-20,50},{-20,-70},{-40,-70},{
                  -70,-30},{-100,-30},{-100,10}},
              lineColor={0,0,0},
              smooth=Smooth.None,
              fillColor={215,230,240},
              fillPattern=FillPattern.Solid)}),
                                Documentation(info="<html>
<p>This icon indicates packages containing interfaces.</p>
</html>"));
    end InterfacesPackage;
    annotation(Documentation(__Dymola_DocumentationClass=true, info="<html>
<p>This package contains definitions for the graphical layout of components which may be used in different libraries. The icons can be utilized by inheriting them in the desired class using &quot;extends&quot; or by directly copying the &quot;icon&quot; layer. </p>
<dl>
<dt><b>Main Authors:</b> </dt>
    <dd><a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a></dd><dd>Deutsches Zentrum fuer Luft und Raumfahrt e.V. (DLR)</dd><dd>Oberpfaffenhofen</dd><dd>Postfach 1116</dd><dd>D-82230 Wessling</dd><dd>email: <a href=\"mailto:Martin.Otter@dlr.de\">Martin.Otter@dlr.de</a></dd><br>
    <dd>Christian Kral</dd><dd><a href=\"http://www.ait.ac.at/\">Austrian Institute of Technology, AIT</a></dd><dd>Mobility Department</dd><dd>Giefinggasse 2</dd><dd>1210 Vienna, Austria</dd><dd>email: <a href=\"mailto:christian.kral@ait.ac.at\">christian.kral@ait.ac.at</a></dd><br>
    <dd align=\"justify\">Johan Andreasson</dd><dd align=\"justify\"><a href=\"http://www.modelon.se/\">Modelon AB</a></dd><dd align=\"justify\">Ideon Science Park</dd><dd align=\"justify\">22370 Lund, Sweden</dd><dd align=\"justify\">email: <a href=\"mailto:johan.andreasson@modelon.se\">johan.andreasson@modelon.se</a></dd>
</dl>
<p>Copyright &copy; 1998-2010, Modelica Association, DLR, AIT, and Modelon AB. </p>
<p><i>This Modelica package is <b>free</b> software; it can be redistributed and/or modified under the terms of the <b>Modelica license</b>, see the license conditions and the accompanying <b>disclaimer</b> in <a href=\"modelica://Modelica.UsersGuide.ModelicaLicense2\">Modelica.UsersGuide.ModelicaLicense2</a>.</i> </p>
</html>"));
  end Icons;

  package SIunits
    "Library of type and unit definitions based on SI units according to ISO 31-1992"
    extends Modelica.Icons.Package;
    annotation (
      Invisible=true,
      Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,
              100}}), graphics={Text(
            extent={{-63,-13},{45,-67}},
            lineColor={0,0,0},
            textString="[kg.m2]")}),
      Documentation(info="<html>
<p>This package provides predefined types, such as <i>Mass</i>,
<i>Angle</i>, <i>Time</i>, based on the international standard
on units, e.g.,
</p>

<pre>   <b>type</b> Angle = Real(<b>final</b> quantity = \"Angle\",
                     <b>final</b> unit     = \"rad\",
                     displayUnit    = \"deg\");
</pre>

<p>
as well as conversion functions from non SI-units to SI-units
and vice versa in subpackage
<a href=\"modelica://Modelica.SIunits.Conversions\">Conversions</a>.
</p>

<p>
For an introduction how units are used in the Modelica standard library
with package SIunits, have a look at:
<a href=\"modelica://Modelica.SIunits.UsersGuide.HowToUseSIunits\">How to use SIunits</a>.
</p>

<p>
Copyright &copy; 1998-2010, Modelica Association and DLR.
</p>
<p>
<i>This Modelica package is <u>free</u> software and the use is completely at <u>your own risk</u>; it can be redistributed and/or modified under the terms of the Modelica License 2. For license conditions (including the disclaimer of warranty) see <a href=\"modelica://Modelica.UsersGuide.ModelicaLicense2\">Modelica.UsersGuide.ModelicaLicense2</a> or visit <a href=\"http://www.modelica.org/licenses/ModelicaLicense2\"> http://www.modelica.org/licenses/ModelicaLicense2</a>.</i>
</p>
</html>",   revisions="<html>
<ul>
<li><i>Jan. 27, 2010</i> by Christian Kral:<br/>Added complex units.</li>
<li><i>Dec. 14, 2005</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br/>Add User&#39;;s Guide and removed &quot;min&quot; values for Resistance and Conductance.</li>
<li><i>October 21, 2002</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a> and <a href=\"http://www.robotic.dlr.de/Christian.Schweiger/\">Christian Schweiger</a>:<br/>Added new package <b>Conversions</b>. Corrected typo <i>Wavelenght</i>.</li>
<li><i>June 6, 2000</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br/>Introduced the following new types<br/>type Temperature = ThermodynamicTemperature;<br/>types DerDensityByEnthalpy, DerDensityByPressure, DerDensityByTemperature, DerEnthalpyByPressure, DerEnergyByDensity, DerEnergyByPressure<br/>Attribute &quot;final&quot; removed from min and max values in order that these values can still be changed to narrow the allowed range of values.<br/>Quantity=&quot;Stress&quot; removed from type &quot;Stress&quot;, in order that a type &quot;Stress&quot; can be connected to a type &quot;Pressure&quot;.</li>
<li><i>Oct. 27, 1999</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br/>New types due to electrical library: Transconductance, InversePotential, Damping.</li>
<li><i>Sept. 18, 1999</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br/>Renamed from SIunit to SIunits. Subpackages expanded, i.e., the SIunits package, does no longer contain subpackages.</li>
<li><i>Aug 12, 1999</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br/>Type &quot;Pressure&quot; renamed to &quot;AbsolutePressure&quot; and introduced a new type &quot;Pressure&quot; which does not contain a minimum of zero in order to allow convenient handling of relative pressure. Redefined BulkModulus as an alias to AbsolutePressure instead of Stress, since needed in hydraulics.</li>
<li><i>June 29, 1999</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br/>Bug-fix: Double definition of &quot;Compressibility&quot; removed and appropriate &quot;extends Heat&quot; clause introduced in package SolidStatePhysics to incorporate ThermodynamicTemperature.</li>
<li><i>April 8, 1998</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a> and Astrid Jaschinski:<br/>Complete ISO 31 chapters realized.</li>
<li><i>Nov. 15, 1997</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a> and <a href=\"http://www.control.lth.se/~hubertus/\">Hubertus Tummescheit</a>:<br/>Some chapters realized.</li>
</ul>
</html>"),
      Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,
              100}}), graphics={
          Rectangle(
            extent={{169,86},{349,236}},
            fillColor={235,235,235},
            fillPattern=FillPattern.Solid,
            lineColor={0,0,255}),
          Polygon(
            points={{169,236},{189,256},{369,256},{349,236},{169,236}},
            fillColor={235,235,235},
            fillPattern=FillPattern.Solid,
            lineColor={0,0,255}),
          Polygon(
            points={{369,256},{369,106},{349,86},{349,236},{369,256}},
            fillColor={235,235,235},
            fillPattern=FillPattern.Solid,
            lineColor={0,0,255}),
          Text(
            extent={{179,226},{339,196}},
            lineColor={160,160,164},
            textString="Library"),
          Text(
            extent={{206,173},{314,119}},
            lineColor={0,0,0},
            textString="[kg.m2]"),
          Text(
            extent={{163,320},{406,264}},
            lineColor={255,0,0},
            textString="Modelica.SIunits")}));
  end SIunits;
annotation (
preferredView="info",
version="3.2",
versionBuild=8,
versionDate="2010-10-25",
dateModified = "2011-09-05 15:20:00Z",
revisionId="",
uses(Complex(version="1.0"), ModelicaServices(version="1.2")),
conversion(
 noneFromVersion="3.1",
 noneFromVersion="3.0.1",
 noneFromVersion="3.0",
 from(version="2.1", script="modelica://Modelica/Resources/Scripts/Dymola/ConvertModelica_from_2.2.2_to_3.0.mos"),
 from(version="2.2", script="modelica://Modelica/Resources/Scripts/Dymola/ConvertModelica_from_2.2.2_to_3.0.mos"),
 from(version="2.2.1", script="modelica://Modelica/Resources/Scripts/Dymola/ConvertModelica_from_2.2.2_to_3.0.mos"),
 from(version="2.2.2", script="modelica://Modelica/Resources/Scripts/Dymola/ConvertModelica_from_2.2.2_to_3.0.mos")),
__Dymola_classOrder={"UsersGuide","Blocks","StateGraph","Electrical","Magnetic","Mechanics","Fluid","Media","Thermal",
      "Math","Utilities","Constants", "Icons", "SIunits"},
Settings(NewStateSelection=true),
Documentation(info="<HTML>
<p>
Package <b>Modelica&reg;</b> is a <b>standardized</b> and <b>free</b> package
that is developed together with the Modelica&reg; language from the
Modelica Association, see
<a href=\"http://www.Modelica.org\">http://www.Modelica.org</a>.
It is also called <b>Modelica Standard Library</b>.
It provides model components in many domains that are based on
standardized interface definitions. Some typical examples are shown
in the next figure:
</p>

<img src=\"modelica://Modelica/Resources/Images/UsersGuide/ModelicaLibraries.png\">

<p>
For an introduction, have especially a look at:
</p>
<ul>
<li> <a href=\"modelica://Modelica.UsersGuide.Overview\">Overview</a>
  provides an overview of the Modelica Standard Library
  inside the <a href=\"modelica://Modelica.UsersGuide\">User's Guide</a>.</li>
<li><a href=\"modelica://Modelica.UsersGuide.ReleaseNotes\">Release Notes</a>
 summarizes the changes of new versions of this package.</li>
<li> <a href=\"modelica://Modelica.UsersGuide.Contact\">Contact</a>
  lists the contributors of the Modelica Standard Library.</li>
<li> The <b>Examples</b> packages in the various libraries, demonstrate
  how to use the components of the corresponding sublibrary.</li>
</ul>

<p>
This version of the Modelica Standard Library consists of
</p>
<ul>
<li> <b>1280</b> models and blocks, and</li>
<li> <b>910</b> functions
</ul>
<p>
that are directly usable (= number of public, non-partial classes).
</p>

<p>
<b>Licensed by the Modelica Association under the Modelica License 2</b><br>
Copyright &copy; 1998-2010, ABB, AIT, T.&nbsp;B&ouml;drich, DLR, Dassault Syst&egrave;mes AB, Fraunhofer, A.Haumer, Modelon,
TU Hamburg-Harburg, Politecnico di Milano.
</p>

<p>
<i>This Modelica package is <u>free</u> software and the use is completely at <u>your own risk</u>; it can be redistributed and/or modified under the terms of the Modelica License 2. For license conditions (including the disclaimer of warranty) see <a href=\"modelica://Modelica.UsersGuide.ModelicaLicense2\">Modelica.UsersGuide.ModelicaLicense2</a> or visit <a href=\"http://www.modelica.org/licenses/ModelicaLicense2\"> http://www.modelica.org/licenses/ModelicaLicense2</a>.</i>
</p>
</HTML>
"));
end Modelica;


package IKEDA

  package Library

    block Constant

      Modelica.Blocks.Interfaces.RealOutput y annotation (Placement(transformation(
              extent={{-30,12},{-10,32}}), iconTransformation(extent={{96,-64},{226,
                66}})));
    parameter Real Const;
    equation
      y=Const;
      annotation (Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,
                -100},{100,100}},
            initialScale=0.04), graphics={Rectangle(
              extent={{-100,100},{100,-100}},
              lineColor={0,0,255},
              lineThickness=0.5), Text(
              extent={{-136,-12},{122,-58}},
              lineColor={0,0,255},
              lineThickness=0.5,
              textString="%Const"),
                                  Text(
              extent={{-136,76},{122,30}},
              lineColor={0,0,255},
              lineThickness=0.5,
              textString="%name")}),  Diagram(coordinateSystem(
            preserveAspectRatio=true,
            extent={{-100,-100},{100,100}},
            initialScale=0.04)));
    end Constant;

    model SimpleSubtract
     extends IKEDA.Library.Interfaces.BaseFactorIcon;

      Modelica.Blocks.Math.Add add(k2=-1)
        annotation (Placement(transformation(extent={{-18,-10},{2,10}})));
      Interfaces.RealInput_ u annotation (Placement(transformation(extent={{
                -116,-26},{-76,14}}), iconTransformation(extent={{-110,-14},{
                -82,14}})));
    equation
      connect(add.u1, yBase) annotation (Line(
          points={{-20,6},{-28,6},{-28,36},{6,36},{6,80}},
          color={0,0,127},
          thickness=0.5,
          smooth=Smooth.None));
      connect(add.y, y) annotation (Line(
          points={{3,0},{12,0},{12,-50},{0,-50},{0,-60}},
          color={0,0,127},
          thickness=0.5,
          smooth=Smooth.None));
      connect(u, add.u2) annotation (Line(
          points={{-96,-6},{-20,-6}},
          color={0,0,127},
          thickness=0.5,
          smooth=Smooth.None));
      annotation (Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
                -100},{100,100}}), graphics), Icon(coordinateSystem(
              preserveAspectRatio=true,  extent={{-100,-100},{100,100}}),
            graphics={Text(
              extent={{-88,20},{-54,-16}},
              lineColor={0,0,255},
              lineThickness=0.5,
              fillColor={213,255,170},
              fillPattern=FillPattern.CrossDiag,
              textString="-")}));
    end SimpleSubtract;

    package Interfaces

      partial model BaseModel

        annotation (Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,
                  -100},{100,100}}), graphics={Rectangle(
                extent={{-100,100},{100,-100}},
                lineColor={0,127,0},
                fillColor={215,215,215},
                fillPattern=FillPattern.Sphere), Text(
                extent={{-100,-74},{100,-52}},
                lineColor={0,0,177},
                fillPattern=FillPattern.VerticalCylinder,
                fillColor={215,215,215},
                textString="%name")}));
      end BaseModel;

      partial model BaseFactorIcon

        RealInput_ yBase annotation (Placement(transformation(extent={{-20,-20},{
                  20,20}},
              rotation=270,
              origin={6,80}),
              iconTransformation(extent={{-10,10},{10,30}}, rotation=-90)));
        RealOutput_ y annotation (Placement(transformation(extent={{-20,-20},{20,
                  20}},
              rotation=270,
              origin={0,-60}),
              iconTransformation(extent={{-10,-30},{10,-10}}, rotation=-90)));

       annotation (
          Icon(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}},
              grid={2,2}), graphics={Rectangle(
                extent={{-100,20},{100,-20}},
                lineColor={95,95,95},
                fillColor={255,255,255},
                fillPattern=FillPattern.Sphere), Text(
                extent={{-90,-10},{92,10}},
                textString="%name",
                lineColor={0,0,0})}), Diagram(coordinateSystem(
                preserveAspectRatio=true, extent={{-100,-100},{100,100}}),
              graphics));
      end BaseFactorIcon;

      connector RealInput = input Real "'input Real' as connector"
        annotation (defaultComponentName="u",
        Icon(graphics={Polygon(
              points={{-100,100},{100,0},{-100,-100},{-100,100}},
              lineColor={0,0,127},
              fillColor={0,0,127},
              fillPattern=FillPattern.Solid), Text(
              extent={{98,-98},{710,120}},
              lineColor={0,0,127},
              textString="%name")},
             coordinateSystem(extent={{-100,-100},{100,100}}, preserveAspectRatio=true, initialScale=0.2)),
        Diagram(coordinateSystem(
              preserveAspectRatio=true, initialScale=0.2,
              extent={{-100,-100},{100,100}},
              grid={1,1}), graphics={Polygon(
              points={{0,50},{100,0},{0,-50},{0,50}},
              lineColor={0,0,127},
              fillColor={0,0,127},
              fillPattern=FillPattern.Solid), Text(
              extent={{-10,85},{-10,60}},
              lineColor={0,0,127},
              textString="%name")}),
          Documentation(info="<html>
<p>
Connector with one input signal of type Real.
</p>
</html>"));

      connector RealInput_ =input Real "'input Real' as connector"
        annotation (defaultComponentName="u",
        Icon(graphics={Polygon(
              points={{-100,100},{100,0},{-100,-100},{-100,100}},
              lineColor={0,0,127},
              fillColor={0,0,127},
              fillPattern=FillPattern.Solid)},
             coordinateSystem(extent={{-100,-100},{100,100}}, preserveAspectRatio=true, initialScale=0.2)),
        Diagram(coordinateSystem(
              preserveAspectRatio=true, initialScale=0.2,
              extent={{-100,-100},{100,100}},
              grid={1,1}), graphics={Polygon(
              points={{0,50},{100,0},{0,-50},{0,50}},
              lineColor={0,0,127},
              fillColor={0,0,127},
              fillPattern=FillPattern.Solid), Text(
              extent={{-10,85},{-10,60}},
              lineColor={0,0,127},
              textString="%name")}),
          Documentation(info="<html>
<p>
Connector with one input signal of type Real.
</p>
</html>"));

      connector RealOutput = output Real "'output Real' as connector"
        annotation (defaultComponentName="u",
        Icon(graphics={Polygon(
              points={{-100,100},{100,0},{-100,-100},{-100,100}},
              lineColor={0,0,127},
              fillColor={255,255,255},
              fillPattern=FillPattern.Solid), Text(
              extent={{-700,-118},{-100,100}},
              lineColor={0,0,127},
              textString="%name")},
             coordinateSystem(extent={{-100,-100},{100,100}}, preserveAspectRatio=true, initialScale=0.2)),
        Diagram(coordinateSystem(
              preserveAspectRatio=true, initialScale=0.2,
              extent={{-100,-100},{100,100}},
              grid={1,1}), graphics={Polygon(
              points={{0,50},{100,0},{0,-50},{0,50}},
              lineColor={0,0,127},
              fillColor={255,255,255},
              fillPattern=FillPattern.Solid), Text(
              extent={{-10,85},{-10,60}},
              lineColor={0,0,127},
              textString="%name")}),
          Documentation(info="<html>
<p>
Connector with one input signal of type Real.
</p>
</html>"));

      connector RealOutput_ =output Real "'output Real' as connector"
        annotation (defaultComponentName="u",
        Icon(graphics={Polygon(
              points={{-100,100},{100,0},{-100,-100},{-100,100}},
              lineColor={0,0,127},
              fillColor={255,255,255},
              fillPattern=FillPattern.Solid)},
             coordinateSystem(extent={{-100,-100},{100,100}}, preserveAspectRatio=true, initialScale=0.2)),
        Diagram(coordinateSystem(
              preserveAspectRatio=true, initialScale=0.2,
              extent={{-100,-100},{100,100}},
              grid={1,1}), graphics={Polygon(
              points={{0,50},{100,0},{0,-50},{0,50}},
              lineColor={0,0,127},
              fillColor={255,255,255},
              fillPattern=FillPattern.Solid)}),
          Documentation(info="<html>
<p>
Connector with one input signal of type Real.
</p>
</html>"));
    end Interfaces;

    package ConcentrationFlow

      replaceable class Concentration = Real (final quantity="Concentration");

      replaceable class SoluteFlow = Real (final quantity="Flow");

      connector ConcentrationFlow "Concentration and Solute flow"
        Concentration conc;
        flow SoluteFlow q;
      end ConcentrationFlow;

      connector PositiveConcentrationFlow "Concentration and Solute inflow"
        extends IKEDA.Library.ConcentrationFlow.ConcentrationFlow;

      annotation (
          defaultComponentName="q_in",
          Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{
                  100,100}}), graphics={Rectangle(
                extent={{-20,10},{20,-10}},
                lineColor={200,0,0},
                lineThickness=1), Polygon(
                points={{0,100},{100,0},{0,-100},{-100,0},{0,100}},
                lineColor={200,0,0},
                smooth=Smooth.None,
                fillPattern=FillPattern.Solid,
                fillColor={200,0,0})}),
          Diagram(Polygon(points=[-21,-3; 5,23; 31,-3; 5,-29; -21,-3],   style(
                color=74,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={0,0,0})), Text(
              extent=[-105,-38; 115,-83],
              string="%name",
              style(color=0, rgbcolor={0,0,0}))),
          Documentation(info="<html>
<p>
Connector with one flow signal of type Real.
</p>
</html>"));
      end PositiveConcentrationFlow;

      connector NegativeConcentrationFlow
        "Concentration and negative Solute outflow"
        extends IKEDA.Library.ConcentrationFlow.ConcentrationFlow;

      annotation (
          defaultComponentName="q_out",
          Icon(coordinateSystem(extent={{-100,-100},{100,100}}, preserveAspectRatio=false),
              graphics={Rectangle(
                extent={{-20,10},{20,-10}},
                lineColor={200,0,0},
                lineThickness=1), Polygon(
                points={{-100,0},{0,100},{100,0},{0,-100},{-100,0}},
                lineColor={200,0,0},
                smooth=Smooth.None,
                fillPattern=FillPattern.Solid,
                fillColor={255,240,240})}),
          Diagram(Polygon(points=[-21,-3; 5,23; 31,-3; 5,-29; -21,-3],   style(
                color=74,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={255,255,255})), Text(
              extent=[-105,-38; 115,-83],
              string="%name",
              style(color=0, rgbcolor={0,0,0}))),
          Documentation(info="<html>
<p>
Connector with one flow signal of type Real.
</p>
</html>"));

      end NegativeConcentrationFlow;

      model InputPump

        IKEDA.Library.ConcentrationFlow.NegativeConcentrationFlow q_out
                               annotation (extent=[-10, -110; 10, -90], Placement(
              transformation(extent={{90,-10},{110,10}}), iconTransformation(extent={
                  {50,-10},{70,10}})));
        IKEDA.Library.Interfaces.RealInput_ desiredFlow "speed of solute flow"
                                                                      annotation ( extent = [-10,30;10,50], rotation = -90);

      equation
        q_out.q = - desiredFlow;

       annotation (
          Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{
                  100,100}}), graphics={
              Rectangle(
                extent={{-60,-30},{60,30}},
                lineColor={0,0,127},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{-48,20},{50,0},{-48,-21},{-48,20}},
                lineColor={0,0,127},
                fillColor={0,0,127},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-92,-54},{80,-30}},
                textString="%name",
                lineColor={0,0,255})}), Diagram(coordinateSystem(preserveAspectRatio=true,
                         extent={{-100,-100},{100,100}}), graphics),
                    Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
                  -100},{100,100}}), graphics));
      end InputPump;

      model OutputPump

        IKEDA.Library.ConcentrationFlow.PositiveConcentrationFlow q_in
                               annotation (extent=[-10, -110; 10, -90], Placement(
              transformation(extent={{-110,-8},{-90,12}}), iconTransformation(extent={{-70,-10},
                  {-50,10}})));
        IKEDA.Library.Interfaces.RealInput_ desiredFlow
                                       annotation ( extent = [-10,30;10,50], rotation = -90);

      equation
        q_in.q = desiredFlow;

       annotation (
          Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{
                  100,100}}), graphics={
              Rectangle(
                extent={{-60,-32},{60,30}},
                lineColor={0,0,127},
                fillColor={255,255,255},
                fillPattern=FillPattern.Solid),
              Polygon(
                points={{-48,18},{50,-2},{-48,-26},{-48,18}},
                lineColor={0,0,127},
                fillColor={0,0,127},
                fillPattern=FillPattern.Solid),
              Text(
                extent={{-78,-54},{72,-32}},
                textString="%name",
                lineColor={0,0,255})}), Diagram(coordinateSystem(preserveAspectRatio=true,
                         extent={{-100,-100},{100,100}}), graphics),
                    Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
                  -100},{100,100}}), graphics));
      end OutputPump;

      model ConcentrationCompartmentIkeda_unknown
         extends IKEDA.Library.Interfaces.BaseModel;

        IKEDA.Library.ConcentrationFlow.NegativeConcentrationFlow q_out
                                   annotation (Placement(
              transformation(extent={{62,-32},{102,8}}),  iconTransformation(extent={{-10,-10},
                  {10,10}})));

       IKEDA.Library.Interfaces.RealInput_ SolventVolume(final quantity="Volume", final unit=
                                                                                            "l")
                                 annotation (Placement(transformation(extent={{-120,68},{-80,108}}),
              iconTransformation(extent={{-120,60},{-80,100}})));
        IKEDA.Library.Interfaces.RealOutput_ SoluteMass
          annotation (Placement(transformation(extent={{-20,-120},{20,-80}}, rotation=
                 -90)));

        IKEDA.Library.Interfaces.RealOutput_ SoluteConc
          annotation (Placement(transformation(extent={{-20,-120},{20,-80}}, rotation=
                 -90), iconTransformation(
              extent={{-20,-120},{20,-80}},
              rotation=0,
              origin={116,32})));
      equation
        SoluteConc=q_out.conc;
        q_out.conc*SolventVolume = SoluteMass;
        der(SoluteMass) = q_out.q;
        annotation (Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
                  -100},{100,100}}), graphics), Icon(coordinateSystem(
                preserveAspectRatio=true, extent={{-100,-100},{100,100}}),
                                                     graphics));
      end ConcentrationCompartmentIkeda_unknown;
    end ConcentrationFlow;
  end Library;

  model O2OxyhemoglobinContent

    Library.Interfaces.RealInput XHB annotation (Placement(transformation(extent={
              {-120,54},{-80,94}}), iconTransformation(extent={{-126,62},{-100,88}})));
    Library.Interfaces.RealInput PO2A annotation (Placement(transformation(extent=
             {{-120,-38},{-80,2}}), iconTransformation(extent={{-126,20},{-100,46}})));
    Library.Interfaces.RealInput PHA annotation (Placement(transformation(extent={
              {-120,4},{-80,44}}), iconTransformation(extent={{-126,-18},{-100,8}})));
    Library.Interfaces.RealOutput UHBO annotation (Placement(transformation(
            extent={{70,46},{110,86}}), iconTransformation(extent={{100,12},{126,38}})));

    Library.Interfaces.RealOutput UHB  annotation (Placement(transformation(
            extent={{70,-2},{110,38}}), iconTransformation(extent={{100,54},{126,80}})));
    Library.Interfaces.RealOutput SO2  annotation (Placement(transformation(
            extent={{70,-42},{110,-2}}),iconTransformation(extent={{100,-42},{126,
              -16}})));

  function F23
    input Real uhb;
    input Real po2a;
    input Real pha;
    output Real uhbo;
  algorithm
    uhbo:=uhb*f(po2a*g(pha));
  end F23;

  function f
    input Real x;
    output Real y;
  algorithm
    y:=(1-exp(-x))^2;
  end f;

  function g
    input Real x;
    output Real y;
  algorithm
    y:=0.0066815*x^3-0.10098*x^2+0.44921*x-0.454;
  end g;

  equation
    UHB=XHB*0.0134;
    UHBO=F23(UHB,PO2A,PHA);
    SO2=UHBO/UHB;
    annotation (Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
              -100},{100,100}}),
                           graphics), Icon(coordinateSystem(preserveAspectRatio=true,
            extent={{-100,-100},{100,100}}), graphics={Text(
            extent={{-82,-18},{68,-128}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="HbO2 cont."), Rectangle(
            extent={{-100,100},{100,-100}},
            lineColor={0,0,255},
            lineThickness=0.5)}));
  end O2OxyhemoglobinContent;

  model ActualBicarbonate

    Library.Interfaces.RealInput STBC annotation (Placement(transformation(extent=
             {{-120,62},{-80,102}}), iconTransformation(extent={{-122,76},{-100,98}})));
    Library.Interfaces.RealInput XHB annotation (Placement(transformation(extent={
              {-120,22},{-80,62}}), iconTransformation(extent={{-122,42},{-100,64}})));
    Library.Interfaces.RealInput PHA annotation (Placement(transformation(extent={
              {-120,-16},{-80,24}}), iconTransformation(extent={{-122,10},{-100,32}})));
    Library.Interfaces.RealInput UHB annotation (Placement(transformation(extent={
              {-120,-54},{-80,-14}}), iconTransformation(extent={{-122,-24},{-100,
              -2}})));
    Library.Interfaces.RealInput UHBO annotation (Placement(transformation(extent=
             {{-120,-90},{-80,-50}}), iconTransformation(extent={{-122,-58},{-100,
              -36}})));
    Library.Interfaces.RealOutput XCO3 annotation (Placement(transformation(
            extent={{80,-10},{120,30}}), iconTransformation(extent={{100,4},{124,28}})));

  function F24
    input Real stbc;
    input Real xhb;
    input Real pha;
    input Real uhb;
    input Real uhbo;
    output Real xco3;
  algorithm
    xco3:=stbc-(0.527*xhb+3.7)*(pha-7.4)+0.375*(uhb-uhbo)/0.0226;
  end F24;

  equation
    XCO3=F24(STBC,XHB,PHA,UHB,UHBO);
   annotation (Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
              -100},{100,100}}),
                           graphics), Icon(coordinateSystem(preserveAspectRatio=true,
            extent={{-100,-100},{100,100}}), graphics={Text(
            extent={{-68,-34},{68,-140}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="act. HCO3"), Rectangle(
            extent={{-100,100},{100,-100}},
            lineColor={0,0,255},
            lineThickness=0.5)}));
  end ActualBicarbonate;

  model HHEquation

    Library.Interfaces.RealInput XCO3 annotation (Placement(transformation(extent=
             {{-120,44},{-80,84}}), iconTransformation(extent={{-124,48},{-100,72}})));
    Library.Interfaces.RealInput PCOA annotation (Placement(transformation(extent=
             {{-120,-40},{-80,0}}), iconTransformation(extent={{-124,8},{-100,32}})));
    Library.Interfaces.RealOutput PHA annotation (Placement(transformation(extent=
             {{76,0},{116,40}}), iconTransformation(extent={{100,8},{126,34}})));

  function HH
    input Real xco3;
    input Real pcoa;
    output Real pha;
  algorithm
    pha:=6.1+Modelica.Math.log10(abs(xco3/(0.03*pcoa)));
  end HH;
  equation
    PHA=HH(XCO3,PCOA);
    annotation (Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,
              -100},{100,100}}), graphics={Rectangle(
            extent={{-100,100},{100,-100}},
            lineColor={0,0,255},
            lineThickness=0.5), Text(
            extent={{-72,-42},{74,-72}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="HH Equation")}), Diagram(coordinateSystem(
            preserveAspectRatio=true, extent={{-100,-100},{100,100}}), graphics));
  end HHEquation;

  model VentilationRatio

    Library.Interfaces.RealInput PHA annotation (Placement(transformation(extent={
              {-120,42},{-80,82}}), iconTransformation(extent={{-122,46},{-100,68}})));
    Library.Interfaces.RealInput PCOA annotation (Placement(transformation(extent=
             {{-120,-34},{-80,6}}), iconTransformation(extent={{-122,16},{-100,38}})));
    Library.Interfaces.RealInput PO2A annotation (Placement(transformation(extent=
             {{-120,-2},{-80,38}}), iconTransformation(extent={{-122,-20},{-100,2}})));
    Library.Interfaces.RealOutput VR annotation (Placement(transformation(extent={
              {60,-4},{100,36}}), iconTransformation(extent={{100,2},{128,30}})));

  function ventRatio
    input Real pha;
    input Real pcoa;
    input Real po2a;
    output Real vr;
    protected
    Real k1;
    Real k2;
    Real k3;
    Real k4;
    Real k5;
    Real k6;
    Real h;
    Real po2;
  algorithm
    po2:=po2a;
    if (pha<=7.4) then
      k1:=0.22;
      k6:=-12.734;
    else
      k1:=0.0258;
      k6:=-5.003;
    end if;
    k3:=0.58;
    k4:=3.496;
    if (pcoa>40) then
      k2:=1;
      k5:=-32.08;
    else
      k2:=0.0396;
      k5:=160.11;
    end if;
    h:=10^(9-pha);
    if (po2==32) then
      po2:=32.001;
    end if;
    vr:=k1*h+k2*(k3+k4/(po2-32))*(pcoa+k5)+k6;
  //teprve kdy? jsou nsledujc ?dky odstran?ny
  //pak to funguje i v DYMOLE 2012 (pro??)
  // if (vr<0.001) then
  //    vr:=0.001;
  //  end if;
  end ventRatio;

  equation
     VR=ventRatio(PHA,PCOA,PO2A);
    annotation (Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
              -100},{100,100}}),
                           graphics), Icon(coordinateSystem(preserveAspectRatio=true,
            extent={{-100,-100},{100,100}}), graphics={
          Rectangle(
            extent={{-100,100},{100,-100}},
            lineColor={0,0,255},
            lineThickness=0.5),
          Text(
            extent={{-88,-36},{78,-70}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="Ventilation"),
          Text(
            extent={{-88,-66},{74,-100}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="ratio")}));
  end VentilationRatio;

  model BloodAcidBaseO2CO2
    Library.Interfaces.RealInput PCO2 annotation (Placement(transformation(
            extent={{-130,-100},{-90,-60}}), iconTransformation(extent={{-118,
              66},{-100,84}})));
    Library.Interfaces.RealInput PO2 annotation (Placement(transformation(
            extent={{-126,4},{-86,44}}), iconTransformation(extent={{-118,36},{
              -100,54}})));
    Library.Interfaces.RealInput XHB annotation (Placement(transformation(
            extent={{-126,32},{-86,72}}), iconTransformation(extent={{-118,-2},
              {-100,16}})));
    Library.Interfaces.RealInput STBC annotation (Placement(transformation(
            extent={{-128,64},{-88,104}}), iconTransformation(extent={{-118,-42},
              {-100,-24}})));
    Library.Interfaces.RealOutput pH annotation (Placement(transformation(
            extent={{76,-30},{116,10}}), iconTransformation(extent={{100,72},{
              120,92}})));
    Library.Interfaces.RealOutput XCO3 annotation (Placement(transformation(
            extent={{72,62},{112,102}}), iconTransformation(extent={{100,42},{
              120,62}})));
    O2OxyhemoglobinContent o2OxyhemoglobinContent
      annotation (Placement(transformation(extent={{-18,0},{18,36}})));
    ActualBicarbonate actualBicarbonate
      annotation (Placement(transformation(extent={{14,44},{52,82}})));
    HHEquation hHEquation
      annotation (Placement(transformation(extent={{-70,-53},{-34,-17}})));
    BloodO2Content bloodO2Content
      annotation (Placement(transformation(extent={{36,-64},{78,-22}})));
    Library.Interfaces.RealOutput UO2 annotation (Placement(transformation(
            extent={{72,-68},{112,-28}}), iconTransformation(extent={{100,-30},
              {120,-10}})));
    Library.Interfaces.RealOutput UCO2 annotation (Placement(transformation(
            extent={{72,-101},{112,-61}}), iconTransformation(extent={{100,-66},
              {120,-46}})));
    BloodCO2Content bloodCO2Content
      annotation (Placement(transformation(extent={{-20,-98},{22,-56}})));
    Library.Interfaces.RealOutput SO2 annotation (Placement(transformation(
            extent={{74,3},{114,43}}), iconTransformation(extent={{100,6},{120,
              26}})));
  equation
    connect(actualBicarbonate.STBC, STBC) annotation (Line(
        points={{11.91,79.53},{-76,79.53},{-76,84},{-108,84}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(actualBicarbonate.XHB, XHB) annotation (Line(
        points={{11.91,73.07},{-80,73.07},{-80,52},{-106,52}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(PO2, o2OxyhemoglobinContent.PO2A) annotation (Line(
        points={{-106,24},{-63.17,24},{-63.17,23.94},{-20.34,23.94}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(hHEquation.PHA, o2OxyhemoglobinContent.PHA) annotation (Line(
        points={{-31.66,-31.22},{-26,-31.22},{-26,17.1},{-20.34,17.1}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(PCO2, hHEquation.PCOA) annotation (Line(
        points={{-110,-80},{-85.08,-80},{-85.08,-31.4},{-72.16,-31.4}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(o2OxyhemoglobinContent.UHBO, actualBicarbonate.UHBO) annotation (
        Line(
        points={{20.34,22.5},{56,22.5},{56,40},{2,40},{2,54.07},{11.91,54.07}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

    connect(actualBicarbonate.XCO3, hHEquation.XCO3) annotation (Line(
        points={{54.28,66.04},{64,66.04},{64,-6},{-80,-6},{-80,-24.2},{-72.16,
            -24.2}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(XCO3, actualBicarbonate.XCO3) annotation (Line(
        points={{92,82},{64,82},{64,66.04},{54.28,66.04}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pH, hHEquation.PHA) annotation (Line(
        points={{96,-10},{-26,-10},{-26,-31.22},{-31.66,-31.22}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(actualBicarbonate.PHA, hHEquation.PHA) annotation (Line(
        points={{11.91,66.99},{-26,66.99},{-26,-31.22},{-31.66,-31.22}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(pH, pH) annotation (Line(
        points={{96,-10},{96,-10}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(bloodO2Content.UHBO, o2OxyhemoglobinContent.UHBO) annotation (Line(
        points={{33.69,-30.61},{28,-30.61},{28,22.5},{20.34,22.5}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(bloodO2Content.PO2, PO2) annotation (Line(
        points={{33.69,-41.11},{-16,-41.11},{-16,-14},{-64,-14},{-64,24},{-106,
            24}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(bloodO2Content.UO2, UO2) annotation (Line(
        points={{80.52,-39.22},{87.26,-39.22},{87.26,-48},{92,-48}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(bloodCO2Content.XCO3, hHEquation.XCO3) annotation (Line(
        points={{-22.31,-64.61},{-80,-64.61},{-80,-24.2},{-72.16,-24.2}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(bloodCO2Content.PCO2, PCO2) annotation (Line(
        points={{-22.31,-75.11},{-58.155,-75.11},{-58.155,-80},{-110,-80}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(UCO2, bloodCO2Content.UCO2) annotation (Line(
        points={{92,-81},{40,-81},{40,-73.22},{24.52,-73.22}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(o2OxyhemoglobinContent.UHB, actualBicarbonate.UHB) annotation (Line(
        points={{20.34,30.06},{26,30.06},{26,38},{-8,38},{-8,60.53},{11.91,
            60.53}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(o2OxyhemoglobinContent.XHB, XHB) annotation (Line(
        points={{-20.34,31.5},{-80,31.5},{-80,52},{-106,52}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(SO2, o2OxyhemoglobinContent.SO2) annotation (Line(
        points={{94,23},{61,23},{61,12.78},{20.34,12.78}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    annotation (Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,
              -100},{100,100}}), graphics={Rectangle(
            extent={{-100,100},{100,-100}},
            lineColor={0,0,255},
            lineThickness=0.5), Text(
            extent={{-82,-64},{58,-94}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="Blood AcidBase")}), Diagram(coordinateSystem(
            preserveAspectRatio=true, extent={{-100,-100},{100,100}}), graphics));
  end BloodAcidBaseO2CO2;

  model BloodO2Content
    Library.Interfaces.RealInput UHBO annotation (Placement(transformation(
            extent={{-120,24},{-80,64}}), iconTransformation(extent={{-122,48},
              {-100,70}})));
    Library.Interfaces.RealInput PO2 annotation (Placement(transformation(
            extent={{-120,-24},{-80,16}}), iconTransformation(extent={{-122,-2},
              {-100,20}})));
    Library.Interfaces.RealOutput UO2 annotation (Placement(transformation(
            extent={{70,0},{110,40}}), iconTransformation(extent={{100,6},{124,
              30}})));
    Library.Constant SO2p(Const=0.00003168)
      annotation (Placement(transformation(extent={{-96,-62},{-78,-44}})));
    Modelica.Blocks.Math.Product product
      annotation (Placement(transformation(extent={{-46,-28},{-16,2}})));
    Modelica.Blocks.Math.Add add
      annotation (Placement(transformation(extent={{24,10},{44,30}})));
  equation
    connect(PO2, product.u1) annotation (Line(
        points={{-100,-4},{-49,-4}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(SO2p.y, product.u2) annotation (Line(
        points={{-72.51,-52.91},{-54,-52.91},{-54,-22},{-49,-22}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(add.y, UO2) annotation (Line(
        points={{45,20},{90,20}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product.y, add.u2) annotation (Line(
        points={{-14.5,-13},{8,-13},{8,14},{22,14}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(UHBO, add.u1) annotation (Line(
        points={{-100,44},{8,44},{8,26},{22,26}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    annotation (Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,
              -100},{100,100}}), graphics={Rectangle(
            extent={{-100,100},{100,-100}},
            lineColor={0,0,255},
            lineThickness=0.5), Text(
            extent={{-86,-36},{50,-100}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="Blood O2 cont.")}), Diagram(coordinateSystem(
            preserveAspectRatio=true, extent={{-100,-100},{100,100}}), graphics));
  end BloodO2Content;

  model BloodCO2Content
    Library.Interfaces.RealInput XCO3 annotation (Placement(transformation(
            extent={{-120,24},{-80,64}}), iconTransformation(extent={{-122,48},
              {-100,70}})));
    Library.Interfaces.RealInput PCO2 annotation (Placement(transformation(
            extent={{-120,-24},{-80,16}}), iconTransformation(extent={{-122,-2},
              {-100,20}})));
    Library.Interfaces.RealOutput UCO2 annotation (Placement(transformation(
            extent={{70,0},{110,40}}), iconTransformation(extent={{100,6},{124,
              30}})));
    Library.Constant SO2p(Const=0.0006732)
      annotation (Placement(transformation(extent={{-96,-62},{-78,-44}})));
    Modelica.Blocks.Math.Product product
      annotation (Placement(transformation(extent={{-46,-28},{-16,2}})));
    Modelica.Blocks.Math.Add add
      annotation (Placement(transformation(extent={{24,10},{44,30}})));
    Library.Constant SO2p1(Const=0.02241)
      annotation (Placement(transformation(extent={{-94,66},{-76,84}})));
    Modelica.Blocks.Math.Product product1
      annotation (Placement(transformation(extent={{-46,38},{-16,68}})));
  equation
    connect(PCO2, product.u1) annotation (Line(
        points={{-100,-4},{-49,-4}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(SO2p.y, product.u2) annotation (Line(
        points={{-72.51,-52.91},{-58,-52.91},{-58,-22},{-49,-22}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(add.y, UCO2) annotation (Line(
        points={{45,20},{90,20}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product.y, add.u2) annotation (Line(
        points={{-14.5,-13},{8,-13},{8,14},{22,14}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(XCO3, product1.u2) annotation (Line(
        points={{-100,44},{-49,44}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(SO2p1.y, product1.u1) annotation (Line(
        points={{-70.51,75.09},{-58,75.09},{-58,62},{-49,62}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product1.y, add.u1) annotation (Line(
        points={{-14.5,53},{6,53},{6,26},{22,26}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    annotation (Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,
              -100},{100,100}}), graphics={Rectangle(
            extent={{-100,100},{100,-100}},
            lineColor={0,0,255},
            lineThickness=0.5), Text(
            extent={{-86,-36},{50,-100}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="Blood CO2 cont.")}),Diagram(coordinateSystem(
            preserveAspectRatio=true, extent={{-100,-100},{100,100}}), graphics));
  end BloodCO2Content;

  model GasExchange

    Library.Interfaces.RealInput MRO2 annotation (Placement(transformation(
            extent={{-124,-114},{-100,-90}}), iconTransformation(extent={{-110,
              80},{-100,90}})));
    Library.Interfaces.RealInput MRCO annotation (Placement(transformation(
          extent={{-12,-12},{12,12}},
          rotation=180,
          origin={112,-94}), iconTransformation(extent={{-110,62},{-100,72}})));
    Library.Interfaces.RealInput QCO annotation (Placement(transformation(
            extent={{-124,-78},{-100,-54}}), iconTransformation(extent={{-110,
              42},{-100,52}})));
    Library.Interfaces.RealInput PBA annotation (Placement(transformation(
            extent={{-124,18},{-100,42}}), iconTransformation(extent={{-110,-20},
              {-100,-10}})));
    Library.Interfaces.RealInput VI annotation (Placement(transformation(extent=
             {{-120,78},{-96,102}}), iconTransformation(extent={{-110,28},{-100,
              38}})));
    Library.Interfaces.RealInput FCOI annotation (Placement(transformation(
            extent={{-124,54},{-100,78}}), iconTransformation(extent={{-110,-4},
              {-100,6}})));
    Library.Interfaces.RealInput FO2I annotation (Placement(transformation(
            extent={{-122,66},{-98,90}}), iconTransformation(extent={{-110,12},
              {-100,22}})));
    Library.Interfaces.RealOutput PCOA annotation (Placement(transformation(
            extent={{88,62},{112,86}}), iconTransformation(extent={{100,56},{
              110,66}})));
    Library.Interfaces.RealOutput PO2A annotation (Placement(transformation(
            extent={{88,46},{112,70}}), iconTransformation(extent={{100,40},{
              110,50}})));
    BloodAcidBaseO2CO2 bloodAcidBaseO2CO2_1
      annotation (Placement(transformation(extent={{57,-42},{85,-14}})));
    Library.Interfaces.RealInput STBC annotation (Placement(transformation(
          extent={{-12,-12},{12,12}},
          rotation=180,
          origin={110,-44}), iconTransformation(extent={{-110,-38},{-100,-28}})));
    Library.Interfaces.RealOutput XCO3 annotation (Placement(transformation(
            extent={{88,12},{112,36}}), iconTransformation(extent={{100,18},{
              110,28}})));
    Library.Interfaces.RealOutput PHA annotation (Placement(transformation(
            extent={{88,28},{112,52}}), iconTransformation(extent={{100,2},{110,
              12}})));
    Library.Interfaces.RealOutput SO2A annotation (Placement(transformation(
            extent={{88,-4},{112,20}}), iconTransformation(extent={{100,-16},{
              110,-6}})));
    Library.Interfaces.RealOutput UO2A annotation (Placement(transformation(
            extent={{88,-20},{112,4}}), iconTransformation(extent={{100,-36},{
              110,-26}})));
    Library.Interfaces.RealOutput UCOA annotation (Placement(transformation(
            extent={{88,-38},{112,-14}}), iconTransformation(extent={{100,-52},
              {110,-42}})));
    Library.Interfaces.RealOutput UO2V annotation (Placement(transformation(
          extent={{-12,-12},{12,12}},
          rotation=180,
          origin={-100,-80}), iconTransformation(extent={{100,-72},{110,-62}})));
    Library.Interfaces.RealOutput UCOV annotation (Placement(transformation(
            extent={{88,-92},{112,-68}}), iconTransformation(extent={{100,-88},
              {110,-78}})));
    Library.Interfaces.RealInput XHB annotation (Placement(transformation(
          extent={{-12,-12},{12,12}},
          rotation=180,
          origin={112,-60}), iconTransformation(extent={{-110,-56},{-100,-46}})));
    Library.Interfaces.RealInput VAL annotation (Placement(transformation(
            extent={{-126,33},{-100,59}}), iconTransformation(extent={{-110,-72},
              {-100,-62}})));
    Library.Interfaces.RealInput VTW annotation (Placement(transformation(
            extent={{-126,-53},{-100,-27}}), iconTransformation(extent={{-110,
              -88},{-100,-78}})));
    Library.ConcentrationFlow.ConcentrationCompartmentIkeda_unknown ZO2ALV(
        SoluteMass(start=0.4419, fixed=false))
      annotation (Placement(transformation(extent={{-60,18},{-40,38}})));
    Library.ConcentrationFlow.ConcentrationCompartmentIkeda_unknown ZCO2ALV(
        SoluteMass(start=0.1683))
      annotation (Placement(transformation(extent={{0,18},{20,38}})));
    Modelica.Blocks.Math.Product product
      annotation (Placement(transformation(extent={{-86,76},{-76,86}})));
    Modelica.Blocks.Math.Product product1
      annotation (Placement(transformation(extent={{-48,76},{-38,86}})));
    Library.ConcentrationFlow.InputPump O2Inflow
      annotation (Placement(transformation(extent={{-100,44},{-72,72}})));
    Library.ConcentrationFlow.InputPump CO2Inflow
      annotation (Placement(transformation(extent={{-24,46},{4,74}})));
    Library.ConcentrationFlow.OutputPump O2Outflow
      annotation (Placement(transformation(extent={{-46,44},{-18,72}})));
    Modelica.Blocks.Math.Product product2 annotation (Placement(transformation(
          extent={{-5,-5},{5,5}},
          rotation=180,
          origin={-29,75})));
    Library.ConcentrationFlow.OutputPump CO2Outflow
      annotation (Placement(transformation(extent={{20,48},{44,72}})));
    Modelica.Blocks.Math.Product product3 annotation (Placement(transformation(
          extent={{-5,-5},{5,5}},
          rotation=180,
          origin={15,77})));
    Modelica.Blocks.Math.Add PBL(k2=-1)
      annotation (Placement(transformation(extent={{-92,22},{-82,32}})));
    Library.Constant PH2O(Const=47) annotation (Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=180,
          origin={-86,12})));
    Modelica.Blocks.Math.Product product4
      annotation (Placement(transformation(extent={{56,2},{66,12}})));
    Modelica.Blocks.Math.Product product5
      annotation (Placement(transformation(extent={{-26,8},{-16,18}})));
    Library.ConcentrationFlow.InputPump VenousO2Inflow annotation (Placement(
          transformation(
          extent={{-14,-14},{14,14}},
          rotation=180,
          origin={-50,-10})));
    Library.ConcentrationFlow.InputPump VenousCO2Inflow annotation (Placement(
          transformation(
          extent={{-14,-14},{14,14}},
          rotation=180,
          origin={5,-8})));
    Library.ConcentrationFlow.OutputPump ArterialO2Outflow annotation (
        Placement(transformation(
          extent={{-14,-14},{14,14}},
          rotation=0,
          origin={-28,-10})));
    Library.ConcentrationFlow.OutputPump ArterialCO2Outflow annotation (
        Placement(transformation(
          extent={{-14.5,-14},{14.5,14}},
          rotation=0,
          origin={28.5,-8})));
    Library.ConcentrationFlow.ConcentrationCompartmentIkeda_unknown ZO2T(
        SoluteMass(start=4.6965))
      annotation (Placement(transformation(extent={{-60,-76},{-40,-56}})));
    Library.ConcentrationFlow.ConcentrationCompartmentIkeda_unknown ZCO2T(
        SoluteMass(start=18.8325))
      annotation (Placement(transformation(extent={{0,-76},{20,-56}})));
    Library.ConcentrationFlow.InputPump ArterialO2Inflow annotation (Placement(
          transformation(
          extent={{-14,-14},{14,14}},
          rotation=180,
          origin={-34,-44})));
    Library.ConcentrationFlow.OutputPump VenousO2Outflow annotation (Placement(
          transformation(
          extent={{-14,-14},{14,14}},
          rotation=180,
          origin={-66,-44})));
    Library.ConcentrationFlow.OutputPump VenousCO2Outflow annotation (Placement(
          transformation(
          extent={{-14.5,-14},{14.5,14}},
          rotation=180,
          origin={-7.5,-45})));
    Library.ConcentrationFlow.InputPump ArterialCO2Inflow annotation (Placement(
          transformation(
          extent={{-14,-14},{14,14}},
          rotation=180,
          origin={26,-46})));
    Modelica.Blocks.Math.Product product6 annotation (Placement(transformation(
          extent={{-5,-5},{5,5}},
          rotation=0,
          origin={-79,-69})));
    Modelica.Blocks.Math.Product product7 annotation (Placement(transformation(
          extent={{-5,-5},{5,5}},
          rotation=0,
          origin={-15,-81})));
    Modelica.Blocks.Math.Product product8 annotation (Placement(transformation(
          extent={{-5,-5},{5,5}},
          rotation=180,
          origin={47,-69})));
    Modelica.Blocks.Math.Product product9 annotation (Placement(transformation(
          extent={{-5,-5},{5,5}},
          rotation=180,
          origin={-28,-63})));
    Modelica.Blocks.Math.Division division annotation (Placement(transformation(
          extent={{-5,-5},{5,5}},
          rotation=180,
          origin={-85,-11})));
    Library.Constant PH2O1(Const=863) annotation (Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=180,
          origin={-68,-14})));
    Modelica.Blocks.Math.Product product10
      annotation (Placement(transformation(extent={{-72,-36},{-62,-26}})));
    Modelica.Blocks.Math.Product product11 annotation (Placement(transformation(
          extent={{-5,-5},{5,5}},
          rotation=180,
          origin={31,-27})));
    Modelica.Blocks.Math.Product product12
      annotation (Placement(transformation(extent={{-32,-34},{-22,-24}})));
    Modelica.Blocks.Math.Product product13
      annotation (Placement(transformation(extent={{-10,-34},{0,-24}})));
    Library.ConcentrationFlow.InputPump CO2production annotation (Placement(
          transformation(
          extent={{-14,-14},{14,14}},
          rotation=180,
          origin={28,-84})));
    Library.ConcentrationFlow.OutputPump O2Consumption annotation (Placement(
          transformation(
          extent={{-14,-14},{14,14}},
          rotation=180,
          origin={-68,-84})));
    Library.Interfaces.RealOutput FCOA annotation (Placement(transformation(
            extent={{42,30},{66,54}}),  iconTransformation(extent={{100,88},{
              110,98}})));
    Library.Interfaces.RealOutput FO2A annotation (Placement(transformation(
            extent={{-42,22},{-22,42}}),iconTransformation(extent={{100,72},{
              110,82}})));
  initial equation
    /*
 ZO2ALV.SoluteMass=0.1473*VAL;
 ZCO2ALV.SoluteMass=0.0561*VAL;
 ZO2T.SoluteMass=0.1515*VTW;
 ZCO2T.SoluteMass=0.6075*VTW;
*/

  equation
    connect(STBC, bloodAcidBaseO2CO2_1.STBC) annotation (Line(
        points={{110,-44},{52,-44},{52,-32.62},{55.74,-32.62}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(XHB, bloodAcidBaseO2CO2_1.XHB) annotation (Line(
        points={{112,-60},{48,-60},{48,-27.02},{55.74,-27.02}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(bloodAcidBaseO2CO2_1.UCO2, UCOA) annotation (Line(
        points={{86.4,-35.84},{98,-35.84},{98,-26},{100,-26}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(bloodAcidBaseO2CO2_1.UO2, UO2A) annotation (Line(
        points={{86.4,-30.8},{94,-30.8},{94,-8},{100,-8}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(bloodAcidBaseO2CO2_1.SO2, SO2A) annotation (Line(
        points={{86.4,-25.76},{91.7,-25.76},{91.7,8},{100,8}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(bloodAcidBaseO2CO2_1.XCO3, XCO3) annotation (Line(
        points={{86.4,-20.72},{90,-20.72},{90,24},{100,24}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(bloodAcidBaseO2CO2_1.pH, PHA) annotation (Line(
        points={{86.4,-16.52},{88,-16.52},{88,40},{100,40}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(VAL, ZO2ALV.SolventVolume) annotation (Line(
        points={{-113,46},{-86,46},{-86,36},{-60,36}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(ZCO2ALV.SolventVolume, VAL) annotation (Line(
        points={{0,36},{-14,36},{-14,46},{-113,46}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product.u1, VI) annotation (Line(
        points={{-87,84},{-92,84},{-92,90},{-108,90}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product.u2, FO2I) annotation (Line(
        points={{-87,78},{-110,78}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(FCOI, product1.u2) annotation (Line(
        points={{-112,66},{-58,66},{-58,78},{-49,78}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(O2Inflow.q_out, ZO2ALV.q_out) annotation (Line(
        points={{-77.6,58},{-56,58},{-56,32},{-50,28}},
        color={200,0,0},
        thickness=1,
        smooth=Smooth.None));
    connect(product.y, O2Inflow.desiredFlow) annotation (Line(
        points={{-75.5,81},{-66,81},{-66,74},{-86,74},{-86,63.6}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product1.u1, VI) annotation (Line(
        points={{-49,84},{-54,84},{-54,90},{-108,90}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product1.y, CO2Inflow.desiredFlow) annotation (Line(
        points={{-37.5,81},{-10,81},{-10,65.6}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(ZCO2ALV.q_out, CO2Inflow.q_out) annotation (Line(
        points={{10,28},{10,28},{4,32},{4,60},{-1.6,60}},
        color={200,0,0},
        thickness=1,
        smooth=Smooth.None));
    connect(O2Outflow.q_in, ZO2ALV.q_out) annotation (Line(
        points={{-40.4,58},{-44,58},{-44,32},{-50,28}},
        color={200,0,0},
        thickness=1,
        smooth=Smooth.None));
    connect(ZCO2ALV.q_out, CO2Outflow.q_in) annotation (Line(
        points={{10,28},{10,28},{18,32},{18,60},{24.8,60}},
        color={200,0,0},
        thickness=1,
        smooth=Smooth.None));
    connect(ZCO2ALV.SoluteConc, product3.u1) annotation (Line(
        points={{21.6,21.2},{44,21.2},{44,74},{21,74}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product3.u2, VI) annotation (Line(
        points={{21,80},{46,80},{46,90},{-108,90}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product2.u2, VI) annotation (Line(
        points={{-23,78},{-12,78},{-12,90},{-108,90}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(ZO2ALV.SoluteConc, product2.u1) annotation (Line(
        points={{-38.4,21.2},{-20,21.2},{-20,72},{-23,72}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product2.y, O2Outflow.desiredFlow) annotation (Line(
        points={{-34.5,75},{-36,75},{-36,66},{-32,66},{-32,63.6}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product3.y, CO2Outflow.desiredFlow) annotation (Line(
        points={{9.5,77},{4,77},{4,68},{32,68},{32,64.8}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(PBL.u1, PBA) annotation (Line(
        points={{-93,30},{-112,30}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(PH2O.y, PBL.u2) annotation (Line(
        points={{-92.44,11.96},{-96,11.96},{-96,24},{-93,24}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product5.u1, ZO2ALV.SoluteConc) annotation (Line(
        points={{-27,16},{-34,16},{-34,21.2},{-38.4,21.2}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product6.y, VenousO2Outflow.desiredFlow) annotation (Line(
        points={{-73.5,-69},{-66,-69},{-66,-49.6}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(ZO2T.SoluteConc, product6.u2) annotation (Line(
        points={{-38.4,-72.8},{-32,-72.8},{-32,-96},{-88,-96},{-88,-72},{-85,
            -72}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product8.u2, bloodAcidBaseO2CO2_1.UCO2) annotation (Line(
        points={{53,-66},{94,-66},{94,-35.84},{86.4,-35.84}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product8.y, ArterialCO2Inflow.desiredFlow) annotation (Line(
        points={{41.5,-69},{26,-69},{26,-51.6}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product9.u2, bloodAcidBaseO2CO2_1.UO2) annotation (Line(
        points={{-22,-60},{-20,-60},{-20,-36},{40,-36},{40,-50},{88,-50},{88,
            -30.8},{86.4,-30.8}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product9.y, ArterialO2Inflow.desiredFlow) annotation (Line(
        points={{-33.5,-63},{-34,-63},{-34,-49.6}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product5.u2, PBL.y) annotation (Line(
        points={{-27,10},{-64,10},{-64,27},{-81.5,27}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product10.y, VenousO2Inflow.desiredFlow) annotation (Line(
        points={{-61.5,-31},{-50,-31},{-50,-15.6}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product10.u2, product6.y) annotation (Line(
        points={{-73,-34},{-78,-34},{-78,-54},{-66,-54},{-66,-69},{-73.5,-69}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

    connect(PH2O1.y, division.u1) annotation (Line(
        points={{-74.44,-14.04},{-77.22,-14.04},{-77.22,-14},{-79,-14}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(division.u2, PBL.y) annotation (Line(
        points={{-79,-8},{-64,-8},{-64,27},{-81.5,27}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(division.y, product10.u1) annotation (Line(
        points={{-90.5,-11},{-94,-11},{-94,-20},{-78,-20},{-78,-28},{-73,-28}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

    connect(product12.u1, division.y) annotation (Line(
        points={{-33,-26},{-36,-26},{-36,-20},{-94,-20},{-94,-11},{-90.5,-11}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

    connect(product12.u2, product9.y) annotation (Line(
        points={{-33,-32},{-42,-32},{-42,-36},{-24,-36},{-24,-56},{-34,-56},{
            -34,-63},{-33.5,-63}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product12.y, ArterialO2Outflow.desiredFlow) annotation (Line(
        points={{-21.5,-29},{-18,-29},{-18,-2},{-28,-2},{-28,-4.4}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product13.u1, division.y) annotation (Line(
        points={{-11,-26},{-16,-26},{-16,-20},{-94,-20},{-94,-11},{-90.5,-11}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

    connect(product13.y, VenousCO2Inflow.desiredFlow) annotation (Line(
        points={{0.5,-29},{5,-29},{5,-13.6}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product11.u1, product8.y) annotation (Line(
        points={{37,-30},{42,-30},{42,-60},{32,-60},{32,-69},{41.5,-69}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product11.u2, division.y) annotation (Line(
        points={{37,-24},{40,-24},{40,-20},{-94,-20},{-94,-11},{-90.5,-11}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(UO2V, ZO2T.SoluteConc) annotation (Line(
        points={{-100,-80},{-88,-80},{-88,-96},{-32,-96},{-32,-72.8},{-38.4,
            -72.8}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(UCOV, ZCO2T.SoluteConc) annotation (Line(
        points={{100,-80},{40,-80},{40,-72.8},{21.6,-72.8}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(O2Consumption.desiredFlow, MRO2) annotation (Line(
        points={{-68,-89.6},{-68,-102},{-112,-102}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(MRCO, CO2production.desiredFlow) annotation (Line(
        points={{112,-94},{28,-94},{28,-89.6}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(ArterialCO2Outflow.desiredFlow, product11.y) annotation (Line(
        points={{28.5,-2.4},{28.5,0},{40,0},{40,-16},{20,-16},{20,-27},{25.5,
          -27}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(ZCO2ALV.SoluteConc, product4.u1) annotation (Line(
        points={{21.6,21.2},{44,21.2},{44,10},{55,10}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product4.u2, PBL.y) annotation (Line(
        points={{55,4},{-64,4},{-64,27},{-81.5,27}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(bloodAcidBaseO2CO2_1.PO2, product5.y) annotation (Line(
        points={{55.74,-21.7},{42,-21.7},{42,13},{-15.5,13}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product4.y, bloodAcidBaseO2CO2_1.PCO2) annotation (Line(
        points={{66.5,7},{74,7},{74,-8},{50,-8},{50,-17.5},{55.74,-17.5}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(PO2A, product5.y) annotation (Line(
        points={{100,58},{78,58},{78,-12},{42,-12},{42,13},{-15.5,13}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(PCOA, product4.y) annotation (Line(
        points={{100,74},{74,74},{74,7},{66.5,7}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(VenousO2Outflow.q_in, ZO2T.q_out) annotation (Line(
        points={{-57.6,-44},{-56,-44},{-56,-66},{-50,-66}},
        color={200,0,0},
        thickness=1,
        smooth=Smooth.None));
    connect(ArterialO2Inflow.q_out, ZO2T.q_out) annotation (Line(
        points={{-42.4,-44},{-46,-44},{-46,-66},{-50,-66}},
        color={200,0,0},
        thickness=1,
        smooth=Smooth.None));
    connect(VenousO2Inflow.q_out, ZO2ALV.q_out) annotation (Line(
        points={{-58.4,-10},{-60,-10},{-60,28},{-50,28}},
        color={200,0,0},
        thickness=1,
        smooth=Smooth.None));
    connect(ArterialO2Outflow.q_in, ZO2ALV.q_out) annotation (Line(
        points={{-36.4,-10},{-38,-10},{-38,0},{-42,0},{-42,28},{-50,28}},
        color={200,0,0},
        thickness=1,
        smooth=Smooth.None));
    connect(ArterialCO2Outflow.q_in, ZCO2ALV.q_out) annotation (Line(
        points={{19.8,-8},{18,-8},{18,28},{10,28}},
        color={200,0,0},
        thickness=1,
        smooth=Smooth.None));
    connect(VenousCO2Inflow.q_out, ZCO2ALV.q_out) annotation (Line(
        points={{-3.4,-8},{-6,-8},{-6,8},{0,8},{0,28},{10,28}},
        color={200,0,0},
        thickness=1,
        smooth=Smooth.None));
    connect(VenousCO2Outflow.q_in, ZCO2T.q_out) annotation (Line(
        points={{1.2,-45},{6,-45},{6,-66},{10,-66}},
        color={200,0,0},
        thickness=1,
        smooth=Smooth.None));
    connect(ArterialCO2Inflow.q_out, ZCO2T.q_out) annotation (Line(
        points={{17.6,-46},{14,-46},{14,-66},{10,-66}},
        color={200,0,0},
        thickness=1,
        smooth=Smooth.None));
    connect(ZO2T.q_out, O2Consumption.q_in) annotation (Line(
        points={{-50,-66},{-50,-70},{-54,-72},{-54,-84},{-59.6,-84}},
        color={200,0,0},
        thickness=1,
        smooth=Smooth.None));
    connect(CO2production.q_out, ZCO2T.q_out) annotation (Line(
        points={{19.6,-84},{16,-84},{16,-72},{10,-66}},
        color={200,0,0},
        thickness=1,
        smooth=Smooth.None));
    connect(product13.u2, product7.y) annotation (Line(
        points={{-11,-32},{-18,-32},{-18,-60},{-8,-60},{-8,-81},{-9.5,-81}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(VenousCO2Outflow.desiredFlow, product7.y) annotation (Line(
        points={{-7.5,-50.6},{-7.5,-58},{-8,-58},{-8,-81},{-9.5,-81}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(ZCO2T.SolventVolume, VTW) annotation (Line(
        points={{0,-58},{-4,-58},{-4,-98},{-94,-98},{-94,-40},{-113,-40}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(ZO2T.SolventVolume, VTW) annotation (Line(
        points={{-60,-58},{-94,-58},{-94,-40},{-113,-40}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product8.u1, QCO) annotation (Line(
        points={{53,-72},{58,-72},{58,-100},{-92,-100},{-92,-66},{-112,-66}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product6.u1, QCO) annotation (Line(
        points={{-85,-66},{-112,-66}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product9.u1, QCO) annotation (Line(
        points={{-22,-66},{-16,-66},{-16,-72},{-26,-72},{-26,-94},{-90,-94},{
            -90,-66},{-112,-66}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product7.u1, QCO) annotation (Line(
        points={{-21,-78},{-26,-78},{-26,-94},{-90,-94},{-90,-66},{-112,-66}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(product7.u2, ZCO2T.SoluteConc) annotation (Line(
        points={{-21,-84},{-24,-84},{-24,-96},{40,-96},{40,-72.8},{21.6,-72.8}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

    connect(ZO2ALV.SoluteConc, FO2A) annotation (Line(
        points={{-38.4,21.2},{-34,21.2},{-34,32},{-32,32}},
        color={0,0,255},
        smooth=Smooth.None,
        thickness=0.5));
    connect(ZCO2ALV.SoluteConc, FCOA) annotation (Line(
        points={{21.6,21.2},{44,21.2},{44,42},{54,42}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    annotation (Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,
              -100},{100,100}}), graphics={Rectangle(
            extent={{-100,100},{100,-100}},
            lineColor={0,0,255},
            lineThickness=0.5), Text(
            extent={{-58,-66},{42,-88}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="O2/CO2 exchange")}), Diagram(coordinateSystem(
            preserveAspectRatio=true, extent={{-100,-100},{100,100}}), graphics));
  end GasExchange;

  model Respiration "blok podle Ikedy"
    Library.Interfaces.RealInput QCO annotation (Placement(transformation(
            extent={{-110,34},{-84,60}}), iconTransformation(extent={{-100,22},
              {-86,36}})));
    Library.Interfaces.RealInput VTW annotation (Placement(transformation(
            extent={{-106,-102},{-78,-74}}), iconTransformation(extent={{-100,
              -20},{-86,-6}})));
    Library.Interfaces.RealInput STBC annotation (Placement(transformation(
            extent={{-104,-40},{-78,-14}}), iconTransformation(extent={{-100,
              -44},{-86,-30}})));
    Library.Interfaces.RealInput FCOI annotation (Placement(transformation(
            extent={{-104,-2},{-78,24}}), iconTransformation(
          extent={{-7,-7},{7,7}},
          rotation=270,
          origin={-63,93})));
    Library.Interfaces.RealInput FO2I annotation (Placement(transformation(
            extent={{-104,16},{-78,42}}), iconTransformation(
          extent={{-7,-7},{7,7}},
          rotation=270,
          origin={-45,93})));
    Library.Interfaces.RealInput PBA annotation (Placement(transformation(
            extent={{-104,-20},{-78,6}}), iconTransformation(
          extent={{-7,-7},{7,7}},
          rotation=270,
          origin={-27,93})));
    Library.Interfaces.RealInput MRCO annotation (Placement(transformation(
            extent={{-106,48},{-80,74}}), iconTransformation(
          extent={{-7,-7},{7,7}},
          rotation=270,
          origin={-7,93})));
    Library.Interfaces.RealInput MRO2 annotation (Placement(transformation(
            extent={{-100,58},{-72,86}}), iconTransformation(
          extent={{-7,-7},{7,7}},
          rotation=270,
          origin={11,93})));
    Library.Interfaces.RealInput XHB annotation (Placement(transformation(
            extent={{-104,-60},{-78,-34}}), iconTransformation(
          extent={{-7,-7},{7,7}},
          rotation=270,
          origin={29,93})));
    Library.Interfaces.RealInput VI0 annotation (Placement(transformation(
            extent={{16,50},{40,74}}),  iconTransformation(
          extent={{-7,-7},{7,7}},
          rotation=270,
          origin={49,93})));
    Library.Interfaces.RealOutput PCOA annotation (Placement(transformation(
            extent={{48,2},{72,26}}), iconTransformation(extent={{86,34},{100,
              48}})));
    Library.Interfaces.RealOutput VI annotation (Placement(transformation(
            extent={{70,58},{90,78}}), iconTransformation(extent={{86,16},{100,
              30}})));
    Library.Interfaces.RealOutput PHA annotation (Placement(transformation(
            extent={{66,-30},{92,-4}}), iconTransformation(extent={{86,-16},{
              100,-2}})));
    Library.Interfaces.RealOutput XCO3 annotation (Placement(transformation(
            extent={{48,-22},{72,2}}), iconTransformation(extent={{86,-42},{100,
              -28}})));
    Library.Interfaces.RealOutput DCLA annotation (Placement(transformation(
            extent={{52,-106},{74,-84}}), iconTransformation(extent={{86,-70},{
              100,-56}})));
    Library.Interfaces.RealOutput UO2V annotation (Placement(transformation(
            extent={{66,-80},{92,-54}}), iconTransformation(
          extent={{-7,-7},{7,7}},
          rotation=270,
          origin={-43,-93})));
    Library.Interfaces.RealOutput UCOV annotation (Placement(transformation(
            extent={{50,-86},{74,-62}}), iconTransformation(
          extent={{-7,-7},{7,7}},
          rotation=270,
          origin={-25,-93})));
    Library.Interfaces.RealOutput FO2A annotation (Placement(transformation(
            extent={{68,14},{92,38}}), iconTransformation(
          extent={{-7,-7},{7,7}},
          rotation=270,
          origin={-9,-93})));
    Library.Interfaces.RealOutput PO2A annotation (Placement(transformation(
            extent={{66,-6},{92,20}}), iconTransformation(
          extent={{-7,-7},{7,7}},
          rotation=270,
          origin={7,-93})));
    Library.Interfaces.RealOutput FCOA annotation (Placement(transformation(
            extent={{50,22},{72,44}}), iconTransformation(
          extent={{-7,-7},{7,7}},
          rotation=270,
          origin={37,-93})));
    GasExchange gasExchange
      annotation (Placement(transformation(extent={{-42,-42},{18,18}})));
    Library.Interfaces.RealInput VAL annotation (Placement(transformation(
            extent={{-104,-80},{-78,-54}}), iconTransformation(
          extent={{-7,-7},{7,7}},
          rotation=270,
          origin={67,93})));
    Library.Interfaces.RealOutput SO2A annotation (Placement(transformation(
            extent={{46,-42},{72,-16}}), iconTransformation(
          extent={{-7,-7},{7,7}},
          rotation=270,
          origin={21,-93})));
    Library.Interfaces.RealOutput UO2A annotation (Placement(transformation(
            extent={{68,-52},{94,-26}}), iconTransformation(
          extent={{-7,-7},{7,7}},
          rotation=270,
          origin={-75,-93})));
    Library.Interfaces.RealOutput UCOA annotation (Placement(transformation(
            extent={{48,-68},{72,-44}}), iconTransformation(
          extent={{-7,-7},{7,7}},
          rotation=270,
          origin={-59,-93})));
    Library.SimpleSubtract simpleSubtract
      annotation (Placement(transformation(extent={{18,-104},{52,-70}})));
    Library.Constant VIconst(Const=5)
      annotation (Placement(transformation(extent={{-80,-82},{-68,-70}})));
  VentilationRatio ventilationRatio
    annotation (Placement(transformation(extent={{-20,54},{22,96}})));
  Modelica.Blocks.Math.Product errorResult
    annotation (Placement(transformation(extent={{50,58},{70,78}})));
  equation
    connect(gasExchange.MRO2, MRO2) annotation (Line(
        points={{-43.5,13.5},{-52,13.5},{-52,72},{-86,72}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasExchange.MRCO, MRCO) annotation (Line(
        points={{-43.5,8.1},{-56,8.1},{-56,61},{-93,61}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasExchange.QCO, QCO) annotation (Line(
        points={{-43.5,2.1},{-62,2.1},{-62,47},{-97,47}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasExchange.FO2I, FO2I) annotation (Line(
        points={{-43.5,-6.9},{-64,-6.9},{-64,29},{-91,29}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasExchange.FCOI, FCOI) annotation (Line(
        points={{-43.5,-11.7},{-66,-11.7},{-66,11},{-91,11}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasExchange.PBA, PBA) annotation (Line(
        points={{-43.5,-16.5},{-71.75,-16.5},{-71.75,-7},{-91,-7}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasExchange.STBC, STBC) annotation (Line(
        points={{-43.5,-21.9},{-72,-21.9},{-72,-27},{-91,-27}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasExchange.XHB, XHB) annotation (Line(
        points={{-43.5,-27.3},{-64,-27.3},{-64,-47},{-91,-47}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasExchange.VAL, VAL) annotation (Line(
        points={{-43.5,-32.1},{-60,-32.1},{-60,-67},{-91,-67}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasExchange.VTW, VTW) annotation (Line(
        points={{-43.5,-36.9},{-54,-36.9},{-54,-88},{-92,-88}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasExchange.FCOA, FCOA) annotation (Line(
        points={{19.5,15.9},{38,15.9},{38,33},{61,33}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasExchange.FO2A, FO2A) annotation (Line(
        points={{19.5,11.1},{44,11.1},{44,26},{80,26}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasExchange.PCOA, PCOA) annotation (Line(
        points={{19.5,6.3},{52,6.3},{52,14},{60,14}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasExchange.PO2A, PO2A) annotation (Line(
        points={{19.5,1.5},{68,1.5},{68,7},{79,7}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasExchange.XCO3, XCO3) annotation (Line(
        points={{19.5,-5.1},{50,-5.1},{50,-10},{60,-10}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasExchange.PHA, PHA) annotation (Line(
        points={{19.5,-9.9},{42,-9.9},{42,-17},{79,-17}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasExchange.SO2A, SO2A) annotation (Line(
        points={{19.5,-15.3},{36,-15.3},{36,-29},{59,-29}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasExchange.UO2A, UO2A) annotation (Line(
        points={{19.5,-21.3},{34,-21.3},{34,-39},{81,-39}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(gasExchange.UCOA, UCOA) annotation (Line(
        points={{19.5,-26.1},{32,-26.1},{32,-56},{60,-56}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

    connect(gasExchange.XCO3, simpleSubtract.yBase) annotation (Line(
        points={{19.5,-5.1},{50,-5.1},{50,-80},{35,-80},{35,-83.6}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(simpleSubtract.u, STBC) annotation (Line(
        points={{18.68,-87},{-46,-87},{-46,-44},{-72,-44},{-72,-27},{-91,-27}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

    connect(simpleSubtract.y, DCLA) annotation (Line(
        points={{35,-90.4},{35,-95},{63,-95}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(UCOV, gasExchange.UCOV) annotation (Line(
        points={{62,-74},{24,-74},{24,-36.9},{19.5,-36.9}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(UO2V, gasExchange.UO2V) annotation (Line(
        points={{79,-67},{28,-67},{28,-32.1},{19.5,-32.1}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
  connect(errorResult.u2, VI0) annotation (Line(
      points={{48,62},{28,62}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(ventilationRatio.VR, errorResult.u1) annotation (Line(
      points={{24.94,78.36},{36,78.36},{36,74},{48,74}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(errorResult.y, VI) annotation (Line(
      points={{71,68},{80,68}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(VIconst.y, gasExchange.VI) annotation (Line(
      points={{-64.34,-75.94},{-56,-75.94},{-56,-2.1},{-43.5,-2.1}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(ventilationRatio.PO2A, gasExchange.PO2A) annotation (Line(
      points={{-22.31,73.11},{-28,73.11},{-28,50},{34,50},{34,1.5},{19.5,1.5}},
      color={0,0,127},
      smooth=Smooth.None,
      thickness=0.5));

  connect(ventilationRatio.PCOA, gasExchange.PCOA) annotation (Line(
      points={{-22.31,80.67},{-34,80.67},{-34,44},{32,44},{32,6.3},{19.5,6.3}},
      color={0,0,127},
      smooth=Smooth.None,
      thickness=0.5));

  connect(ventilationRatio.PHA, gasExchange.PHA) annotation (Line(
      points={{-22.31,86.97},{-42,86.97},{-42,40},{28,40},{28,-9.9},{19.5,-9.9}},
      color={0,0,127},
      smooth=Smooth.None,
      thickness=0.5));

    annotation (Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,
              -100},{100,100}}), graphics={Rectangle(
            extent={{-86,86},{86,-86}},
            lineColor={0,0,255},
            lineThickness=0.5), Text(
            extent={{-107,11},{107,-11}},
            lineColor={0,0,255},
            lineThickness=0.5,
            textString="RESPIRATION",
            origin={1,5},
            rotation=180)}), Diagram(coordinateSystem(preserveAspectRatio=true,
            extent={{-100,-100},{100,100}}), graphics));
  end Respiration;

  model testRespirationBlock
    Respiration respiration
      annotation (Placement(transformation(extent={{-56,-70},{72,58}})));
    Library.Constant STBC(Const=24)
      annotation (Placement(transformation(extent={{-98,-36},{-90,-28}})));
    Library.Constant VTW(Const=31)
      annotation (Placement(transformation(extent={{-88,-26},{-80,-18}})));
    Library.Constant QCO(Const=5)
      annotation (Placement(transformation(extent={{-84,6},{-76,14}})));
    Library.Constant FCOI(Const=0)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=270,
          origin={-34,80})));
    Library.Constant FO2I(Const=0.210)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=270,
          origin={-24,90})));
    Library.Constant PBA(Const=760)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=270,
          origin={-12,72})));
    Library.Constant MRCO(Const=0.2318)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=270,
          origin={-2,82})));
    Library.Constant MRO2(Const=0.2591)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=270,
          origin={14,86})));
    Library.Constant XHB(Const=15)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=270,
          origin={26,74})));
    Library.Constant XHB1(Const=5)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=270,
          origin={40,82})));
    Library.Constant XHB2(Const=3)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=270,
          origin={50,92})));
  equation
    connect(STBC.y, respiration.STBC) annotation (Line(
        points={{-87.56,-31.96},{-70.78,-31.96},{-70.78,-29.68},{-51.52,-29.68}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

    connect(VTW.y, respiration.VTW) annotation (Line(
        points={{-77.56,-21.96},{-65.78,-21.96},{-65.78,-14.32},{-51.52,-14.32}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));

    connect(QCO.y, respiration.QCO) annotation (Line(
        points={{-73.56,10.04},{-59.78,10.04},{-59.78,12.56},{-51.52,12.56}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(FCOI.y, respiration.FCOI) annotation (Line(
        points={{-33.96,73.56},{-33.96,64.78},{-32.32,64.78},{-32.32,53.52}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(FO2I.y, respiration.FO2I) annotation (Line(
        points={{-23.96,83.56},{-23.96,69.78},{-20.8,69.78},{-20.8,53.52}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(PBA.y, respiration.PBA) annotation (Line(
        points={{-11.96,65.56},{-11.96,61.78},{-9.28,61.78},{-9.28,53.52}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(MRCO.y, respiration.MRCO) annotation (Line(
        points={{-1.96,75.56},{-1.96,63.78},{3.52,63.78},{3.52,53.52}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(MRO2.y, respiration.MRO2) annotation (Line(
        points={{14.04,79.56},{14.04,68.78},{15.04,68.78},{15.04,53.52}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(XHB.y, respiration.XHB) annotation (Line(
        points={{26.04,67.56},{26.04,59.78},{26.56,59.78},{26.56,53.52}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(XHB1.y, respiration.VI0) annotation (Line(
        points={{40.04,75.56},{40.04,63.78},{39.36,63.78},{39.36,53.52}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    connect(XHB2.y, respiration.VAL) annotation (Line(
        points={{50.04,85.56},{50.04,69.78},{50.88,69.78},{50.88,53.52}},
        color={0,0,127},
        thickness=0.5,
        smooth=Smooth.None));
    annotation (Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-100,
            -100},{100,100}}),        graphics));
  end testRespirationBlock;
  annotation (uses(Modelica(version="3.2")));
end IKEDA;

model IKEDA_testRespirationBlock
 extends IKEDA.testRespirationBlock;
  annotation(experiment(
    StopTime=1,
    NumberOfIntervals=500,
    Tolerance=0.0001,
    Algorithm="dassl"),
    Diagram(graphics),
    uses(Modelica(version="3.2")));
end IKEDA_testRespirationBlock;
